Module: Google::Apis::CalendarV3
- Defined in:
- lib/google/apis/calendar_v3.rb,
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/service.rb,
lib/google/apis/calendar_v3/gem_version.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
Calendar API
Manipulates events and other calendar data.
Defined Under Namespace
Classes: Acl, AclRule, Calendar, CalendarList, CalendarListEntry, CalendarNotification, CalendarService, Channel, ColorDefinition, Colors, ConferenceData, ConferenceParameters, ConferenceParametersAddOnParameters, ConferenceProperties, ConferenceRequestStatus, ConferenceSolution, ConferenceSolutionKey, CreateConferenceRequest, EntryPoint, Error, Event, EventAttachment, EventAttendee, EventBirthdayProperties, EventDateTime, EventFocusTimeProperties, EventOutOfOfficeProperties, EventReminder, EventWorkingLocationProperties, Events, FreeBusyCalendar, FreeBusyGroup, FreeBusyRequest, FreeBusyRequestItem, FreeBusyResponse, Setting, Settings, TimePeriod
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-calendar_v3 gem
"0.51.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20251207"- VERSION =
Version of the Calendar API this client connects to. This is NOT the gem version.
'V3'- AUTH_CALENDAR =
See, edit, share, and permanently delete all the calendars you can access using Google Calendar
'https://www.googleapis.com/auth/calendar'- AUTH_CALENDAR_ACLS =
See and change the sharing permissions of Google calendars you own
'https://www.googleapis.com/auth/calendar.acls'- AUTH_CALENDAR_ACLS_READONLY =
See the sharing permissions of Google calendars you own
'https://www.googleapis.com/auth/calendar.acls.readonly'- AUTH_CALENDAR_APP_CREATED =
Make secondary Google calendars, and see, create, change, and delete events on them
'https://www.googleapis.com/auth/calendar.app.created'- AUTH_CALENDAR_CALENDARLIST =
See, add, and remove Google calendars you’re subscribed to
'https://www.googleapis.com/auth/calendar.calendarlist'- AUTH_CALENDAR_CALENDARLIST_READONLY =
See the list of Google calendars you’re subscribed to
'https://www.googleapis.com/auth/calendar.calendarlist.readonly'- AUTH_CALENDAR_CALENDARS =
See and change the properties of Google calendars you have access to, and create secondary calendars
'https://www.googleapis.com/auth/calendar.calendars'- AUTH_CALENDAR_CALENDARS_READONLY =
See the title, description, default time zone, and other properties of Google calendars you have access to
'https://www.googleapis.com/auth/calendar.calendars.readonly'- AUTH_CALENDAR_EVENTS =
View and edit events on all your calendars
'https://www.googleapis.com/auth/calendar.events'- AUTH_CALENDAR_EVENTS_FREEBUSY =
See the availability on Google calendars you have access to
'https://www.googleapis.com/auth/calendar.events.freebusy'- AUTH_CALENDAR_EVENTS_OWNED =
See, create, change, and delete events on Google calendars you own
'https://www.googleapis.com/auth/calendar.events.owned'- AUTH_CALENDAR_EVENTS_OWNED_READONLY =
See the events on Google calendars you own
'https://www.googleapis.com/auth/calendar.events.owned.readonly'- AUTH_CALENDAR_EVENTS_PUBLIC_READONLY =
See the events on public calendars
'https://www.googleapis.com/auth/calendar.events.public.readonly'- AUTH_CALENDAR_EVENTS_READONLY =
View events on all your calendars
'https://www.googleapis.com/auth/calendar.events.readonly'- AUTH_CALENDAR_FREEBUSY =
View your availability in your calendars
'https://www.googleapis.com/auth/calendar.freebusy'- AUTH_CALENDAR_READONLY =
See and download any calendar you can access using your Google Calendar
'https://www.googleapis.com/auth/calendar.readonly'- AUTH_CALENDAR_SETTINGS_READONLY =
View your Calendar settings
'https://www.googleapis.com/auth/calendar.settings.readonly'