Class: Google::Apis::CalendarV3::AclRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AclRule

Returns a new instance of AclRule.



112
113
114
# File 'lib/google/apis/calendar_v3/classes.rb', line 112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


78
79
80
# File 'lib/google/apis/calendar_v3/classes.rb', line 78

def etag
  @etag
end

#idString

Identifier of the Access Control List (ACL) rule. See Sharing calendars. Corresponds to the JSON property id

Returns:

  • (String)


83
84
85
# File 'lib/google/apis/calendar_v3/classes.rb', line 83

def id
  @id
end

#kindString

Type of the resource ("calendar#aclRule"). Corresponds to the JSON property kind

Returns:

  • (String)


88
89
90
# File 'lib/google/apis/calendar_v3/classes.rb', line 88

def kind
  @kind
end

#roleString

The role assigned to the scope. Possible values are:

  • "none" - Provides no access.
  • "freeBusyReader" - Provides read access to free/busy information.
  • "reader" - Provides read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
  • "writer" - Provides read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible. Provides read access to the calendar's ACLs.
  • "owner" - Provides manager access to the calendar. This role has all of the permissions of the writer role with the additional ability to modify access levels of other users. Important: the owner role is different from the calendar's data owner. A calendar has a single data owner, but can have multiple users with owner role. Corresponds to the JSON property role

Returns:

  • (String)


105
106
107
# File 'lib/google/apis/calendar_v3/classes.rb', line 105

def role
  @role
end

#scopeGoogle::Apis::CalendarV3::AclRule::Scope

The extent to which calendar access is granted by this ACL rule. Corresponds to the JSON property scope



110
111
112
# File 'lib/google/apis/calendar_v3/classes.rb', line 110

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



117
118
119
120
121
122
123
# File 'lib/google/apis/calendar_v3/classes.rb', line 117

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @role = args[:role] if args.key?(:role)
  @scope = args[:scope] if args.key?(:scope)
end