Class: Google::Apis::CalendarV3::Channel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Channel

Returns a new instance of Channel.



575
576
577
# File 'lib/google/apis/calendar_v3/classes.rb', line 575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The address where notifications are delivered for this channel. Corresponds to the JSON property address

Returns:

  • (String)


521
522
523
# File 'lib/google/apis/calendar_v3/classes.rb', line 521

def address
  @address
end

#expirationFixnum

Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional. Corresponds to the JSON property expiration

Returns:

  • (Fixnum)


527
528
529
# File 'lib/google/apis/calendar_v3/classes.rb', line 527

def expiration
  @expiration
end

#idString

A UUID or similar unique string that identifies this channel. Corresponds to the JSON property id

Returns:

  • (String)


532
533
534
# File 'lib/google/apis/calendar_v3/classes.rb', line 532

def id
  @id
end

#kindString

Identifies this as a notification channel used to watch for changes to a resource, which is "api#channel". Corresponds to the JSON property kind

Returns:

  • (String)


538
539
540
# File 'lib/google/apis/calendar_v3/classes.rb', line 538

def kind
  @kind
end

#paramsHash<String,String>

Additional parameters controlling delivery channel behavior. Optional. Corresponds to the JSON property params

Returns:

  • (Hash<String,String>)


543
544
545
# File 'lib/google/apis/calendar_v3/classes.rb', line 543

def params
  @params
end

#payloadBoolean Also known as: payload?

A Boolean value to indicate whether payload is wanted. Optional. Corresponds to the JSON property payload

Returns:

  • (Boolean)


548
549
550
# File 'lib/google/apis/calendar_v3/classes.rb', line 548

def payload
  @payload
end

#resource_idString

An opaque ID that identifies the resource being watched on this channel. Stable across different API versions. Corresponds to the JSON property resourceId

Returns:

  • (String)


555
556
557
# File 'lib/google/apis/calendar_v3/classes.rb', line 555

def resource_id
  @resource_id
end

#resource_uriString

A version-specific identifier for the watched resource. Corresponds to the JSON property resourceUri

Returns:

  • (String)


560
561
562
# File 'lib/google/apis/calendar_v3/classes.rb', line 560

def resource_uri
  @resource_uri
end

#tokenString

An arbitrary string delivered to the target address with each notification delivered over this channel. Optional. Corresponds to the JSON property token

Returns:

  • (String)


566
567
568
# File 'lib/google/apis/calendar_v3/classes.rb', line 566

def token
  @token
end

#typeString

The type of delivery mechanism used for this channel. Valid values are " web_hook" (or "webhook"). Both values refer to a channel where Http requests are used to deliver messages. Corresponds to the JSON property type

Returns:

  • (String)


573
574
575
# File 'lib/google/apis/calendar_v3/classes.rb', line 573

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/google/apis/calendar_v3/classes.rb', line 580

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @expiration = args[:expiration] if args.key?(:expiration)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @params = args[:params] if args.key?(:params)
  @payload = args[:payload] if args.key?(:payload)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @token = args[:token] if args.key?(:token)
  @type = args[:type] if args.key?(:type)
end