Class: Google::Apis::CalendarV3::ConferenceData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConferenceData

Returns a new instance of ConferenceData.



732
733
734
# File 'lib/google/apis/calendar_v3/classes.rb', line 732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conference_idString

The ID of the conference. Can be used by developers to keep track of conferences, should not be displayed to users. The ID value is formed differently for each conference solution type:

  • eventHangout: ID is not set. (This conference type is deprecated.)
  • eventNamedHangout: ID is the name of the Hangout. (This conference type is deprecated.)
  • hangoutsMeet: ID is the 10-letter meeting code, for example aaa-bbbb-ccc.
  • addOn: ID is defined by the third-party provider. Optional. Corresponds to the JSON property conferenceId

Returns:

  • (String)


683
684
685
# File 'lib/google/apis/calendar_v3/classes.rb', line 683

def conference_id
  @conference_id
end

#conference_solutionGoogle::Apis::CalendarV3::ConferenceSolution

The conference solution, such as Google Meet. Unset for a conference with a failed create request. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property conferenceSolution



691
692
693
# File 'lib/google/apis/calendar_v3/classes.rb', line 691

def conference_solution
  @conference_solution
end

#create_requestGoogle::Apis::CalendarV3::CreateConferenceRequest

A request to generate a new conference and attach it to the event. The data is generated asynchronously. To see whether the data is present check the status field. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property createRequest



700
701
702
# File 'lib/google/apis/calendar_v3/classes.rb', line 700

def create_request
  @create_request
end

#entry_pointsArray<Google::Apis::CalendarV3::EntryPoint>

Information about individual conference entry points, such as URLs or phone numbers. All of them must belong to the same conference. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property entryPoints



709
710
711
# File 'lib/google/apis/calendar_v3/classes.rb', line 709

def entry_points
  @entry_points
end

#notesString

Additional notes (such as instructions from the domain administrator, legal notices) to display to the user. Can contain HTML. The maximum length is 2048 characters. Optional. Corresponds to the JSON property notes

Returns:

  • (String)


716
717
718
# File 'lib/google/apis/calendar_v3/classes.rb', line 716

def notes
  @notes
end

#parametersGoogle::Apis::CalendarV3::ConferenceParameters

Additional properties related to a conference. An example would be a solution- specific setting for enabling video streaming. Corresponds to the JSON property parameters



722
723
724
# File 'lib/google/apis/calendar_v3/classes.rb', line 722

def parameters
  @parameters
end

#signatureString

The signature of the conference data. Generated on server side. Unset for a conference with a failed create request. Optional for a conference with a pending create request. Corresponds to the JSON property signature

Returns:

  • (String)


730
731
732
# File 'lib/google/apis/calendar_v3/classes.rb', line 730

def signature
  @signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



737
738
739
740
741
742
743
744
745
# File 'lib/google/apis/calendar_v3/classes.rb', line 737

def update!(**args)
  @conference_id = args[:conference_id] if args.key?(:conference_id)
  @conference_solution = args[:conference_solution] if args.key?(:conference_solution)
  @create_request = args[:create_request] if args.key?(:create_request)
  @entry_points = args[:entry_points] if args.key?(:entry_points)
  @notes = args[:notes] if args.key?(:notes)
  @parameters = args[:parameters] if args.key?(:parameters)
  @signature = args[:signature] if args.key?(:signature)
end