Class: Google::Apis::CalendarV3::ConferenceSolution
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::ConferenceSolution
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#icon_uri ⇒ String
The user-visible icon for this solution.
-
#key ⇒ Google::Apis::CalendarV3::ConferenceSolutionKey
The key which can uniquely identify the conference solution for this event.
-
#name ⇒ String
The user-visible name of this solution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConferenceSolution
constructor
A new instance of ConferenceSolution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConferenceSolution
Returns a new instance of ConferenceSolution.
838 839 840 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#icon_uri ⇒ String
The user-visible icon for this solution.
Corresponds to the JSON property iconUri
826 827 828 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 826 def icon_uri @icon_uri end |
#key ⇒ Google::Apis::CalendarV3::ConferenceSolutionKey
The key which can uniquely identify the conference solution for this event.
Corresponds to the JSON property key
831 832 833 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 831 def key @key end |
#name ⇒ String
The user-visible name of this solution. Not localized.
Corresponds to the JSON property name
836 837 838 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 836 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
843 844 845 846 847 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 843 def update!(**args) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |