Class: Google::Apis::CalendarV3::CreateConferenceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateConferenceRequest

Returns a new instance of CreateConferenceRequest.



914
915
916
# File 'lib/google/apis/calendar_v3/classes.rb', line 914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conference_solution_keyGoogle::Apis::CalendarV3::ConferenceSolutionKey

The conference solution, such as Hangouts or Google Meet. Corresponds to the JSON property conferenceSolutionKey



900
901
902
# File 'lib/google/apis/calendar_v3/classes.rb', line 900

def conference_solution_key
  @conference_solution_key
end

#request_idString

The client-generated unique ID for this request. Clients should regenerate this ID for every new request. If an ID provided is the same as for the previous request, the request is ignored. Corresponds to the JSON property requestId

Returns:

  • (String)


907
908
909
# File 'lib/google/apis/calendar_v3/classes.rb', line 907

def request_id
  @request_id
end

#statusGoogle::Apis::CalendarV3::ConferenceRequestStatus

The status of the conference create request. Corresponds to the JSON property status



912
913
914
# File 'lib/google/apis/calendar_v3/classes.rb', line 912

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



919
920
921
922
923
# File 'lib/google/apis/calendar_v3/classes.rb', line 919

def update!(**args)
  @conference_solution_key = args[:conference_solution_key] if args.key?(:conference_solution_key)
  @request_id = args[:request_id] if args.key?(:request_id)
  @status = args[:status] if args.key?(:status)
end