Class: Google::Apis::CalendarV3::EntryPoint
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EntryPoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#access_code ⇒ String
The access code to access the conference.
-
#entry_point_features ⇒ Array<String>
Features of the entry point, such as being toll or toll-free.
-
#entry_point_type ⇒ String
The type of the conference entry point.
-
#label ⇒ String
The label for the URI.
-
#meeting_code ⇒ String
The meeting code to access the conference.
-
#passcode ⇒ String
The passcode to access the conference.
-
#password ⇒ String
The password to access the conference.
-
#pin ⇒ String
The PIN to access the conference.
-
#region_code ⇒ String
The CLDR/ISO 3166 region code for the country associated with this phone access.
-
#uri ⇒ String
The URI of the entry point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntryPoint
constructor
A new instance of EntryPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntryPoint
Returns a new instance of EntryPoint.
1027 1028 1029 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_code ⇒ String
The access code to access the conference. The maximum length is 128 characters.
When creating new conference data, populate only the subset of meetingCode,
accessCode, passcode, password, pin fields that match the terminology that
the conference provider uses. Only the populated fields should be displayed.
Optional.
Corresponds to the JSON property accessCode
937 938 939 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 937 def access_code @access_code end |
#entry_point_features ⇒ Array<String>
Features of the entry point, such as being toll or toll-free. One entry point
can have multiple features. However, toll and toll-free cannot be both set on
the same entry point.
Corresponds to the JSON property entryPointFeatures
944 945 946 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 944 def entry_point_features @entry_point_features end |
#entry_point_type ⇒ String
The type of the conference entry point. Possible values are:
- "video" - joining a conference over HTTP. A conference can have zero or one video entry point.
- "phone" - joining a conference by dialing a phone number. A conference can have zero or more phone entry points.
- "sip" - joining a conference over SIP. A conference can have zero or one sip entry point.
- "more" - further conference joining instructions, for example additional
phone numbers. A conference can have zero or one more entry point. A
conference with only a more entry point is not a valid conference.
Corresponds to the JSON property
entryPointType
959 960 961 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 959 def entry_point_type @entry_point_type end |
#label ⇒ String
The label for the URI. Visible to end users. Not localized. The maximum length is 512 characters. Examples:
- for video: meet.google.com/aaa-bbbb-ccc
- for phone: +1 123 268 2601
- for sip: 12345678@altostrat.com
- for more: should not be filled
Optional.
Corresponds to the JSON property
label
971 972 973 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 971 def label @label end |
#meeting_code ⇒ String
The meeting code to access the conference. The maximum length is 128
characters.
When creating new conference data, populate only the subset of meetingCode,
accessCode, passcode, password, pin fields that match the terminology that
the conference provider uses. Only the populated fields should be displayed.
Optional.
Corresponds to the JSON property meetingCode
981 982 983 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 981 def meeting_code @meeting_code end |
#passcode ⇒ String
The passcode to access the conference. The maximum length is 128 characters.
When creating new conference data, populate only the subset of meetingCode,
accessCode, passcode, password, pin fields that match the terminology that
the conference provider uses. Only the populated fields should be displayed.
Corresponds to the JSON property passcode
989 990 991 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 989 def passcode @passcode end |
#password ⇒ String
The password to access the conference. The maximum length is 128 characters.
When creating new conference data, populate only the subset of meetingCode,
accessCode, passcode, password, pin fields that match the terminology that
the conference provider uses. Only the populated fields should be displayed.
Optional.
Corresponds to the JSON property password
998 999 1000 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 998 def password @password end |
#pin ⇒ String
The PIN to access the conference. The maximum length is 128 characters.
When creating new conference data, populate only the subset of meetingCode,
accessCode, passcode, password, pin fields that match the terminology that
the conference provider uses. Only the populated fields should be displayed.
Optional.
Corresponds to the JSON property pin
1007 1008 1009 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1007 def pin @pin end |
#region_code ⇒ String
The CLDR/ISO 3166 region code for the country associated with this phone
access. Example: "SE" for Sweden.
Calendar backend will populate this field only for EntryPointType.PHONE.
Corresponds to the JSON property regionCode
1014 1015 1016 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1014 def region_code @region_code end |
#uri ⇒ String
The URI of the entry point. The maximum length is 1300 characters. Format:
- for video, http: or https: schema is required.
- for phone, tel: schema is required. The URI should include the entire dial sequence (e.g., tel:+12345678900,,,123456789;1234).
- for sip, sip: schema is required, e.g., sip:12345678@myprovider.com.
- for more, http: or https: schema is required.
Corresponds to the JSON property
uri
1025 1026 1027 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1025 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1032 def update!(**args) @access_code = args[:access_code] if args.key?(:access_code) @entry_point_features = args[:entry_point_features] if args.key?(:entry_point_features) @entry_point_type = args[:entry_point_type] if args.key?(:entry_point_type) @label = args[:label] if args.key?(:label) @meeting_code = args[:meeting_code] if args.key?(:meeting_code) @passcode = args[:passcode] if args.key?(:passcode) @password = args[:password] if args.key?(:password) @pin = args[:pin] if args.key?(:pin) @region_code = args[:region_code] if args.key?(:region_code) @uri = args[:uri] if args.key?(:uri) end |