Class: Google::Apis::CalendarV3::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



1068
1069
1070
# File 'lib/google/apis/calendar_v3/classes.rb', line 1068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Domain, or broad category, of the error. Corresponds to the JSON property domain

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/calendar_v3/classes.rb', line 1053

def domain
  @domain
end

#reasonString

Specific reason for the error. Some of the possible values are:

  • "groupTooBig" - The group of users requested is too large for a single query.

  • "tooManyCalendarsRequested" - The number of calendars requested is too large for a single query.

  • "notFound" - The requested resource was not found.

  • "internalError" - The API service has encountered an internal error. Additional error types may be added in the future, so clients should gracefully handle additional error statuses not included in this list. Corresponds to the JSON property reason

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/calendar_v3/classes.rb', line 1066

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1073
1074
1075
1076
# File 'lib/google/apis/calendar_v3/classes.rb', line 1073

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @reason = args[:reason] if args.key?(:reason)
end