Class: Google::Apis::CalendarV3::Event::ExtendedProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

Extended properties of the event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtendedProperties

Returns a new instance of ExtendedProperties.



1508
1509
1510
# File 'lib/google/apis/calendar_v3/classes.rb', line 1508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#privateHash<String,String>

Properties that are private to the copy of the event that appears on this calendar. Corresponds to the JSON property private

Returns:

  • (Hash<String,String>)


1500
1501
1502
# File 'lib/google/apis/calendar_v3/classes.rb', line 1500

def private
  @private
end

#sharedHash<String,String>

Properties that are shared between copies of the event on other attendees' calendars. Corresponds to the JSON property shared

Returns:

  • (Hash<String,String>)


1506
1507
1508
# File 'lib/google/apis/calendar_v3/classes.rb', line 1506

def shared
  @shared
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1513
1514
1515
1516
# File 'lib/google/apis/calendar_v3/classes.rb', line 1513

def update!(**args)
  @private = args[:private] if args.key?(:private)
  @shared = args[:shared] if args.key?(:shared)
end