Class: Google::Apis::CalendarV3::Event::Gadget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Gadget

Returns a new instance of Gadget.



1589
1590
1591
# File 'lib/google/apis/calendar_v3/classes.rb', line 1589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_modeString

The gadget's display mode. Deprecated. Possible values are:

  • "icon" - The gadget displays next to the event's title in the calendar view.
  • "chip" - The gadget displays when the event is clicked. Corresponds to the JSON property display

Returns:

  • (String)


1550
1551
1552
# File 'lib/google/apis/calendar_v3/classes.rb', line 1550

def display_mode
  @display_mode
end

#heightFixnum

The gadget's height in pixels. The height must be an integer greater than 0. Optional. Deprecated. Corresponds to the JSON property height

Returns:

  • (Fixnum)


1556
1557
1558
# File 'lib/google/apis/calendar_v3/classes.rb', line 1556

def height
  @height
end

The gadget's icon URL. The URL scheme must be HTTPS. Deprecated. Corresponds to the JSON property iconLink

Returns:

  • (String)


1561
1562
1563
# File 'lib/google/apis/calendar_v3/classes.rb', line 1561

def icon_link
  @icon_link
end

The gadget's URL. The URL scheme must be HTTPS. Deprecated. Corresponds to the JSON property link

Returns:

  • (String)


1566
1567
1568
# File 'lib/google/apis/calendar_v3/classes.rb', line 1566

def link
  @link
end

#preferencesHash<String,String>

Preferences. Corresponds to the JSON property preferences

Returns:

  • (Hash<String,String>)


1571
1572
1573
# File 'lib/google/apis/calendar_v3/classes.rb', line 1571

def preferences
  @preferences
end

#titleString

The gadget's title. Deprecated. Corresponds to the JSON property title

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/calendar_v3/classes.rb', line 1576

def title
  @title
end

#typeString

The gadget's type. Deprecated. Corresponds to the JSON property type

Returns:

  • (String)


1581
1582
1583
# File 'lib/google/apis/calendar_v3/classes.rb', line 1581

def type
  @type
end

#widthFixnum

The gadget's width in pixels. The width must be an integer greater than 0. Optional. Deprecated. Corresponds to the JSON property width

Returns:

  • (Fixnum)


1587
1588
1589
# File 'lib/google/apis/calendar_v3/classes.rb', line 1587

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
# File 'lib/google/apis/calendar_v3/classes.rb', line 1594

def update!(**args)
  @display_mode = args[:display_mode] if args.key?(:display_mode)
  @height = args[:height] if args.key?(:height)
  @icon_link = args[:icon_link] if args.key?(:icon_link)
  @link = args[:link] if args.key?(:link)
  @preferences = args[:preferences] if args.key?(:preferences)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @width = args[:width] if args.key?(:width)
end