Class: Google::Apis::CalendarV3::Event::Source

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

Source from which the event was created. For example, a web page, an email message or any document identifiable by an URL with HTTP or HTTPS scheme. Can only be seen or modified by the creator of the event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



1695
1696
1697
# File 'lib/google/apis/calendar_v3/classes.rb', line 1695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#titleString

Title of the source; for example a title of a web page or an email subject. Corresponds to the JSON property title

Returns:

  • (String)


1688
1689
1690
# File 'lib/google/apis/calendar_v3/classes.rb', line 1688

def title
  @title
end

#urlString

URL of the source pointing to a resource. The URL scheme must be HTTP or HTTPS. Corresponds to the JSON property url

Returns:

  • (String)


1693
1694
1695
# File 'lib/google/apis/calendar_v3/classes.rb', line 1693

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1700
1701
1702
1703
# File 'lib/google/apis/calendar_v3/classes.rb', line 1700

def update!(**args)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end