Class: Google::Apis::CalendarV3::EventAttendee
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventAttendee
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#additional_guests ⇒ Fixnum
Number of additional guests.
-
#async_operation ⇒ String
If present, indicates the status of an asynchronous operation ongoing for this attendee (e.g. listing of members of large attendee groups).
-
#comment ⇒ String
The attendee's response comment.
-
#display_name ⇒ String
The attendee's name, if available.
-
#email ⇒ String
The attendee's email address, if available.
-
#id ⇒ String
The attendee's Profile ID, if available.
-
#optional ⇒ Boolean
(also: #optional?)
Whether this is an optional attendee.
-
#organizer ⇒ Boolean
(also: #organizer?)
Whether the attendee is the organizer of the event.
-
#resource ⇒ Boolean
(also: #resource?)
Whether the attendee is a resource.
-
#response_status ⇒ String
The attendee's response status.
-
#self ⇒ Boolean
(also: #self?)
Whether this entry represents the calendar on which this copy of the event appears.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventAttendee
constructor
A new instance of EventAttendee.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventAttendee
Returns a new instance of EventAttendee.
1853 1854 1855 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_guests ⇒ Fixnum
Number of additional guests. Optional. The default is 0.
Corresponds to the JSON property additionalGuests
1775 1776 1777 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1775 def additional_guests @additional_guests end |
#async_operation ⇒ String
If present, indicates the status of an asynchronous operation ongoing for this attendee (e.g. listing of members of large attendee groups). Read-only. The default is to not be present. Possible values are:
- "inProgress" - The asynchronous operation is in progress.
- (not present) - Otherwise.
Corresponds to the JSON property
asyncOperation
1785 1786 1787 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1785 def async_operation @async_operation end |
#comment ⇒ String
The attendee's response comment. Optional.
Corresponds to the JSON property comment
1790 1791 1792 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1790 def comment @comment end |
#display_name ⇒ String
The attendee's name, if available. Optional.
Corresponds to the JSON property displayName
1795 1796 1797 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1795 def display_name @display_name end |
#email ⇒ String
The attendee's email address, if available. This field must be present when
adding an attendee. It must be a valid email address as per RFC5322.
Required when adding an attendee.
Corresponds to the JSON property email
1802 1803 1804 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1802 def email @email end |
#id ⇒ String
The attendee's Profile ID, if available.
Corresponds to the JSON property id
1807 1808 1809 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1807 def id @id end |
#optional ⇒ Boolean Also known as: optional?
Whether this is an optional attendee. Optional. The default is False.
Corresponds to the JSON property optional
1812 1813 1814 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1812 def optional @optional end |
#organizer ⇒ Boolean Also known as: organizer?
Whether the attendee is the organizer of the event. Read-only. The default is
False.
Corresponds to the JSON property organizer
1819 1820 1821 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1819 def organizer @organizer end |
#resource ⇒ Boolean Also known as: resource?
Whether the attendee is a resource. Can only be set when the attendee is added
to the event for the first time. Subsequent modifications are ignored.
Optional. The default is False.
Corresponds to the JSON property resource
1827 1828 1829 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1827 def resource @resource end |
#response_status ⇒ String
The attendee's response status. Possible values are:
- "needsAction" - The attendee has not responded to the invitation ( recommended for new events).
- "declined" - The attendee has declined the invitation.
- "tentative" - The attendee has tentatively accepted the invitation.
- "accepted" - The attendee has accepted the invitation. Warning: If you add
an event using the values declined, tentative, or accepted, attendees with the
"Add invitations to my calendar" setting set to "When I respond to invitation
in email" or "Only if the sender is known" might have their response reset to
needsAction and won't see an event in their calendar unless they change their
response in the event invitation email. Furthermore, if more than 200 guests
are invited to the event, response status is not propagated to the guests.
Corresponds to the JSON property
responseStatus
1844 1845 1846 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1844 def response_status @response_status end |
#self ⇒ Boolean Also known as: self?
Whether this entry represents the calendar on which this copy of the event
appears. Read-only. The default is False.
Corresponds to the JSON property self
1850 1851 1852 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1850 def self @self end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1858 def update!(**args) @additional_guests = args[:additional_guests] if args.key?(:additional_guests) @async_operation = args[:async_operation] if args.key?(:async_operation) @comment = args[:comment] if args.key?(:comment) @display_name = args[:display_name] if args.key?(:display_name) @email = args[:email] if args.key?(:email) @id = args[:id] if args.key?(:id) @optional = args[:optional] if args.key?(:optional) @organizer = args[:organizer] if args.key?(:organizer) @resource = args[:resource] if args.key?(:resource) @response_status = args[:response_status] if args.key?(:response_status) @self = args[:self] if args.key?(:self) end |