Class: Google::Apis::CalendarV3::EventBirthdayProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventBirthdayProperties

Returns a new instance of EventBirthdayProperties.



1860
1861
1862
# File 'lib/google/apis/calendar_v3/classes.rb', line 1860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contactString

Resource name of the contact this birthday event is linked to. This can be used to fetch contact details from People API. Format: "people/c12345". Read- only. Corresponds to the JSON property contact

Returns:

  • (String)


1838
1839
1840
# File 'lib/google/apis/calendar_v3/classes.rb', line 1838

def contact
  @contact
end

#custom_type_nameString

Custom type label specified for this event. This is populated if birthdayProperties.type is set to "custom". Read-only. Corresponds to the JSON property customTypeName

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/calendar_v3/classes.rb', line 1844

def custom_type_name
  @custom_type_name
end

#typeString

Type of birthday or special event. Possible values are:

  • "anniversary" - An anniversary other than birthday. Always has a contact.
  • "birthday" - A birthday event. This is the default value.
  • "custom" - A special date whose label is further specified in the customTypeName field. Always has a contact.
  • "other" - A special date which does not fall into the other categories, and does not have a custom label. Always has a contact.
  • "self" - Calendar owner's own birthday. Cannot have a contact. The Calendar API only supports creating events with the type "birthday". The type cannot be changed after the event is created. Corresponds to the JSON property type

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/calendar_v3/classes.rb', line 1858

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1865
1866
1867
1868
1869
# File 'lib/google/apis/calendar_v3/classes.rb', line 1865

def update!(**args)
  @contact = args[:contact] if args.key?(:contact)
  @custom_type_name = args[:custom_type_name] if args.key?(:custom_type_name)
  @type = args[:type] if args.key?(:type)
end