Class: Google::Apis::CalendarV3::EventFocusTimeProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventFocusTimeProperties

Returns a new instance of EventFocusTimeProperties.



1968
1969
1970
# File 'lib/google/apis/calendar_v3/classes.rb', line 1968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_decline_modeString

Whether to decline meeting invitations which overlap Focus Time events. Valid values are declineNone, meaning that no meeting invitations are declined; declineAllConflictingInvitations, meaning that all conflicting meeting invitations that conflict with the event are declined; and declineOnlyNewConflictingInvitations, meaning that only new conflicting meeting invitations which arrive while the Focus Time event is present are to be declined. Corresponds to the JSON property autoDeclineMode

Returns:

  • (String)


1954
1955
1956
# File 'lib/google/apis/calendar_v3/classes.rb', line 1954

def auto_decline_mode
  @auto_decline_mode
end

#chat_statusString

The status to mark the user in Chat and related products. This can be available or doNotDisturb. Corresponds to the JSON property chatStatus

Returns:

  • (String)


1960
1961
1962
# File 'lib/google/apis/calendar_v3/classes.rb', line 1960

def chat_status
  @chat_status
end

#decline_messageString

Response message to set if an existing event or new invitation is automatically declined by Calendar. Corresponds to the JSON property declineMessage

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/calendar_v3/classes.rb', line 1966

def decline_message
  @decline_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1973
1974
1975
1976
1977
# File 'lib/google/apis/calendar_v3/classes.rb', line 1973

def update!(**args)
  @auto_decline_mode = args[:auto_decline_mode] if args.key?(:auto_decline_mode)
  @chat_status = args[:chat_status] if args.key?(:chat_status)
  @decline_message = args[:decline_message] if args.key?(:decline_message)
end