Class: Google::Apis::CalendarV3::EventLabel
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventLabel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#background_color ⇒ String
Background color of the label in hexadecimal format, such as "#039be5".
-
#id ⇒ String
The ID of the label.
-
#name ⇒ String
Name of the label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventLabel
constructor
A new instance of EventLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventLabel
Returns a new instance of EventLabel.
2015 2016 2017 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ String
Background color of the label in hexadecimal format, such as "#039be5". Events
with this label are displayed in this color. Required.
Corresponds to the JSON property backgroundColor
2000 2001 2002 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2000 def background_color @background_color end |
#id ⇒ String
The ID of the label. Optional when inserting a new label. If not provided, a
unique ID will be generated. Required when updating a label.
If provided, the ID must be unique within the calendar and follow UUID format.
Corresponds to the JSON property id
2007 2008 2009 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2007 def id @id end |
#name ⇒ String
Name of the label. Optional.
If provided this must have at most 50 characters.
Corresponds to the JSON property name
2013 2014 2015 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2013 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2020 2021 2022 2023 2024 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2020 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |