Class: Google::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
If present, specifies that the user is working from an office.
Instance Attribute Summary collapse
-
#building_id ⇒ String
An optional building identifier.
-
#desk_id ⇒ String
An optional desk identifier.
-
#floor_id ⇒ String
An optional floor identifier.
-
#floor_section_id ⇒ String
An optional floor section identifier.
-
#label ⇒ String
The office name that's displayed in Calendar Web and Mobile clients.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OfficeLocation
constructor
A new instance of OfficeLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OfficeLocation
Returns a new instance of OfficeLocation.
2182 2183 2184 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#building_id ⇒ String
An optional building identifier. This should reference a building ID in the
organization's Resources database.
Corresponds to the JSON property buildingId
2158 2159 2160 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2158 def building_id @building_id end |
#desk_id ⇒ String
An optional desk identifier.
Corresponds to the JSON property deskId
2163 2164 2165 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2163 def desk_id @desk_id end |
#floor_id ⇒ String
An optional floor identifier.
Corresponds to the JSON property floorId
2168 2169 2170 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2168 def floor_id @floor_id end |
#floor_section_id ⇒ String
An optional floor section identifier.
Corresponds to the JSON property floorSectionId
2173 2174 2175 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2173 def floor_section_id @floor_section_id end |
#label ⇒ String
The office name that's displayed in Calendar Web and Mobile clients. We
recommend you reference a building name in the organization's Resources
database.
Corresponds to the JSON property label
2180 2181 2182 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2180 def label @label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2187 def update!(**args) @building_id = args[:building_id] if args.key?(:building_id) @desk_id = args[:desk_id] if args.key?(:desk_id) @floor_id = args[:floor_id] if args.key?(:floor_id) @floor_section_id = args[:floor_section_id] if args.key?(:floor_section_id) @label = args[:label] if args.key?(:label) end |