Class: Google::Apis::CalendarV3::Settings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



2553
2554
2555
# File 'lib/google/apis/calendar_v3/classes.rb', line 2553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of the collection. Corresponds to the JSON property etag

Returns:

  • (String)


2528
2529
2530
# File 'lib/google/apis/calendar_v3/classes.rb', line 2528

def etag
  @etag
end

#itemsArray<Google::Apis::CalendarV3::Setting>

List of user settings. Corresponds to the JSON property items



2533
2534
2535
# File 'lib/google/apis/calendar_v3/classes.rb', line 2533

def items
  @items
end

#kindString

Type of the collection ("calendar#settings"). Corresponds to the JSON property kind

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/calendar_v3/classes.rb', line 2538

def kind
  @kind
end

#next_page_tokenString

Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2544
2545
2546
# File 'lib/google/apis/calendar_v3/classes.rb', line 2544

def next_page_token
  @next_page_token
end

#next_sync_tokenString

Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided. Corresponds to the JSON property nextSyncToken

Returns:

  • (String)


2551
2552
2553
# File 'lib/google/apis/calendar_v3/classes.rb', line 2551

def next_sync_token
  @next_sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2558
2559
2560
2561
2562
2563
2564
# File 'lib/google/apis/calendar_v3/classes.rb', line 2558

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token)
end