Class: Google::Apis::CalendarV3::Calendar
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Calendar
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#auto_accept_invitations ⇒ Boolean
(also: #auto_accept_invitations?)
Whether this calendar automatically accepts invitations.
-
#conference_properties ⇒ Google::Apis::CalendarV3::ConferenceProperties
Conferencing properties for this calendar, for example what types of conferences are allowed.
-
#data_owner ⇒ String
The email of the owner of the calendar.
-
#description ⇒ String
Description of the calendar.
-
#etag ⇒ String
ETag of the resource.
-
#id ⇒ String
Identifier of the calendar.
-
#kind ⇒ String
Type of the resource ("calendar#calendar").
-
#label_properties ⇒ Google::Apis::CalendarV3::LabelProperties
Label properties defined on this calendar.
-
#location ⇒ String
Geographic location of the calendar as free-form text.
-
#summary ⇒ String
Title of the calendar.
-
#time_zone ⇒ String
The time zone of the calendar.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Calendar
constructor
A new instance of Calendar.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Calendar
Returns a new instance of Calendar.
224 225 226 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_accept_invitations ⇒ Boolean Also known as: auto_accept_invitations?
Whether this calendar automatically accepts invitations. Only valid for
resource calendars.
Corresponds to the JSON property autoAcceptInvitations
165 166 167 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 165 def auto_accept_invitations @auto_accept_invitations end |
#conference_properties ⇒ Google::Apis::CalendarV3::ConferenceProperties
Conferencing properties for this calendar, for example what types of
conferences are allowed.
Corresponds to the JSON property conferenceProperties
172 173 174 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 172 def conference_properties @conference_properties end |
#data_owner ⇒ String
The email of the owner of the calendar. Set only for secondary calendars. Read-
only.
Corresponds to the JSON property dataOwner
178 179 180 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 178 def data_owner @data_owner end |
#description ⇒ String
Description of the calendar. Optional.
Corresponds to the JSON property description
183 184 185 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 183 def description @description end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
188 189 190 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 188 def etag @etag end |
#id ⇒ String
Identifier of the calendar. To retrieve IDs call the calendarList.list()
method.
Corresponds to the JSON property id
194 195 196 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 194 def id @id end |
#kind ⇒ String
Type of the resource ("calendar#calendar").
Corresponds to the JSON property kind
199 200 201 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 199 def kind @kind end |
#label_properties ⇒ Google::Apis::CalendarV3::LabelProperties
Label properties defined on this calendar. If specified, overwrites the
existing label properties. If not specified, the label properties remain
unchanged.
Corresponds to the JSON property labelProperties
206 207 208 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 206 def label_properties @label_properties end |
#location ⇒ String
Geographic location of the calendar as free-form text. Optional.
Corresponds to the JSON property location
211 212 213 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 211 def location @location end |
#summary ⇒ String
Title of the calendar.
Corresponds to the JSON property summary
216 217 218 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 216 def summary @summary end |
#time_zone ⇒ String
The time zone of the calendar. (Formatted as an IANA Time Zone Database name,
e.g. "Europe/Zurich".) Optional.
Corresponds to the JSON property timeZone
222 223 224 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 222 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 229 def update!(**args) @auto_accept_invitations = args[:auto_accept_invitations] if args.key?(:auto_accept_invitations) @conference_properties = args[:conference_properties] if args.key?(:conference_properties) @data_owner = args[:data_owner] if args.key?(:data_owner) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_properties = args[:label_properties] if args.key?(:label_properties) @location = args[:location] if args.key?(:location) @summary = args[:summary] if args.key?(:summary) @time_zone = args[:time_zone] if args.key?(:time_zone) end |