Class: Google::Apis::CalendarV3::CalendarList
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::CalendarList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
ETag of the collection.
-
#items ⇒ Array<Google::Apis::CalendarV3::CalendarListEntry>
Calendars that are present on the user's calendar list.
-
#kind ⇒ String
Type of the collection ("calendar#calendarList").
-
#next_page_token ⇒ String
Token used to access the next page of this result.
-
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarList
constructor
A new instance of CalendarList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarList
Returns a new instance of CalendarList.
279 280 281 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
ETag of the collection.
Corresponds to the JSON property etag
254 255 256 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 254 def etag @etag end |
#items ⇒ Array<Google::Apis::CalendarV3::CalendarListEntry>
Calendars that are present on the user's calendar list.
Corresponds to the JSON property items
259 260 261 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 259 def items @items end |
#kind ⇒ String
Type of the collection ("calendar#calendarList").
Corresponds to the JSON property kind
264 265 266 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 264 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. Omitted if no further
results are available, in which case nextSyncToken is provided.
Corresponds to the JSON property nextPageToken
270 271 272 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 270 def next_page_token @next_page_token end |
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have
changed since this result was returned. Omitted if further results are
available, in which case nextPageToken is provided.
Corresponds to the JSON property nextSyncToken
277 278 279 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 277 def next_sync_token @next_sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
284 285 286 287 288 289 290 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 284 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token) end |