Class: Google::Apis::CalendarV3::CalendarList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarList

Returns a new instance of CalendarList.



276
277
278
# File 'lib/google/apis/calendar_v3/classes.rb', line 276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

ETag of the collection. Corresponds to the JSON property etag

Returns:

  • (String)


251
252
253
# File 'lib/google/apis/calendar_v3/classes.rb', line 251

def etag
  @etag
end

#itemsArray<Google::Apis::CalendarV3::CalendarListEntry>

Calendars that are present on the user's calendar list. Corresponds to the JSON property items



256
257
258
# File 'lib/google/apis/calendar_v3/classes.rb', line 256

def items
  @items
end

#kindString

Type of the collection ("calendar#calendarList"). Corresponds to the JSON property kind

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/calendar_v3/classes.rb', line 261

def kind
  @kind
end

#next_page_tokenString

Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


267
268
269
# File 'lib/google/apis/calendar_v3/classes.rb', line 267

def next_page_token
  @next_page_token
end

#next_sync_tokenString

Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided. Corresponds to the JSON property nextSyncToken

Returns:

  • (String)


274
275
276
# File 'lib/google/apis/calendar_v3/classes.rb', line 274

def next_sync_token
  @next_sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



281
282
283
284
285
286
287
# File 'lib/google/apis/calendar_v3/classes.rb', line 281

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token)
end