Class: Google::Apis::CalendarV3::CalendarList
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::CalendarList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
ETag of the collection.
-
#items ⇒ Array<Google::Apis::CalendarV3::CalendarListEntry>
Calendars that are present on the user's calendar list.
-
#kind ⇒ String
Type of the collection ("calendar#calendarList").
-
#next_page_token ⇒ String
Token used to access the next page of this result.
-
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarList
constructor
A new instance of CalendarList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarList
Returns a new instance of CalendarList.
276 277 278 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
ETag of the collection.
Corresponds to the JSON property etag
251 252 253 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 251 def etag @etag end |
#items ⇒ Array<Google::Apis::CalendarV3::CalendarListEntry>
Calendars that are present on the user's calendar list.
Corresponds to the JSON property items
256 257 258 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 256 def items @items end |
#kind ⇒ String
Type of the collection ("calendar#calendarList").
Corresponds to the JSON property kind
261 262 263 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 261 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. Omitted if no further
results are available, in which case nextSyncToken is provided.
Corresponds to the JSON property nextPageToken
267 268 269 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 267 def next_page_token @next_page_token end |
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have
changed since this result was returned. Omitted if further results are
available, in which case nextPageToken is provided.
Corresponds to the JSON property nextSyncToken
274 275 276 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 274 def next_sync_token @next_sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
281 282 283 284 285 286 287 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 281 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token) end |