Class: Google::Apis::CalendarV3::Channel
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Channel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#address ⇒ String
The address where notifications are delivered for this channel.
-
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
-
#id ⇒ String
A UUID or similar unique string that identifies this channel.
-
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a resource, which is "api#channel".
-
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior.
-
#payload ⇒ Boolean
(also: #payload?)
A Boolean value to indicate whether payload is wanted.
-
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
-
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
-
#token ⇒ String
An arbitrary string delivered to the target address with each notification delivered over this channel.
-
#type ⇒ String
The type of delivery mechanism used for this channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
575 576 577 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The address where notifications are delivered for this channel.
Corresponds to the JSON property address
521 522 523 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 521 def address @address end |
#expiration ⇒ Fixnum
Date and time of notification channel expiration, expressed as a Unix
timestamp, in milliseconds. Optional.
Corresponds to the JSON property expiration
527 528 529 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 527 def expiration @expiration end |
#id ⇒ String
A UUID or similar unique string that identifies this channel.
Corresponds to the JSON property id
532 533 534 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 532 def id @id end |
#kind ⇒ String
Identifies this as a notification channel used to watch for changes to a
resource, which is "api#channel".
Corresponds to the JSON property kind
538 539 540 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 538 def kind @kind end |
#params ⇒ Hash<String,String>
Additional parameters controlling delivery channel behavior. Optional.
Corresponds to the JSON property params
543 544 545 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 543 def params @params end |
#payload ⇒ Boolean Also known as: payload?
A Boolean value to indicate whether payload is wanted. Optional.
Corresponds to the JSON property payload
548 549 550 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 548 def payload @payload end |
#resource_id ⇒ String
An opaque ID that identifies the resource being watched on this channel.
Stable across different API versions.
Corresponds to the JSON property resourceId
555 556 557 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 555 def resource_id @resource_id end |
#resource_uri ⇒ String
A version-specific identifier for the watched resource.
Corresponds to the JSON property resourceUri
560 561 562 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 560 def resource_uri @resource_uri end |
#token ⇒ String
An arbitrary string delivered to the target address with each notification
delivered over this channel. Optional.
Corresponds to the JSON property token
566 567 568 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 566 def token @token end |
#type ⇒ String
The type of delivery mechanism used for this channel. Valid values are "
web_hook" (or "webhook"). Both values refer to a channel where Http requests
are used to deliver messages.
Corresponds to the JSON property type
573 574 575 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 573 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 580 def update!(**args) @address = args[:address] if args.key?(:address) @expiration = args[:expiration] if args.key?(:expiration) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @params = args[:params] if args.key?(:params) @payload = args[:payload] if args.key?(:payload) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @token = args[:token] if args.key?(:token) @type = args[:type] if args.key?(:type) end |