Class: Google::Apis::CalendarV3::ConferenceData
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::ConferenceData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#conference_id ⇒ String
The ID of the conference.
-
#conference_solution ⇒ Google::Apis::CalendarV3::ConferenceSolution
The conference solution, such as Google Meet.
-
#create_request ⇒ Google::Apis::CalendarV3::CreateConferenceRequest
A request to generate a new conference and attach it to the event.
-
#entry_points ⇒ Array<Google::Apis::CalendarV3::EntryPoint>
Information about individual conference entry points, such as URLs or phone numbers.
-
#notes ⇒ String
Additional notes (such as instructions from the domain administrator, legal notices) to display to the user.
-
#parameters ⇒ Google::Apis::CalendarV3::ConferenceParameters
Additional properties related to a conference.
-
#signature ⇒ String
The signature of the conference data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConferenceData
constructor
A new instance of ConferenceData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConferenceData
Returns a new instance of ConferenceData.
726 727 728 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conference_id ⇒ String
The ID of the conference. Can be used by developers to keep track of conferences, should not be displayed to users. The ID value is formed differently for each conference solution type:
- eventHangout: ID is not set. (This conference type is deprecated.)
- eventNamedHangout: ID is the name of the Hangout. (This conference type is deprecated.)
- hangoutsMeet: ID is the 10-letter meeting code, for example aaa-bbbb-ccc.
- addOn: ID is defined by the third-party provider. Optional.
Corresponds to the JSON property
conferenceId
677 678 679 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 677 def conference_id @conference_id end |
#conference_solution ⇒ Google::Apis::CalendarV3::ConferenceSolution
The conference solution, such as Google Meet.
Unset for a conference with a failed create request.
Either conferenceSolution and at least one entryPoint, or createRequest is
required.
Corresponds to the JSON property conferenceSolution
685 686 687 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 685 def conference_solution @conference_solution end |
#create_request ⇒ Google::Apis::CalendarV3::CreateConferenceRequest
A request to generate a new conference and attach it to the event. The data is
generated asynchronously. To see whether the data is present check the status
field.
Either conferenceSolution and at least one entryPoint, or createRequest is
required.
Corresponds to the JSON property createRequest
694 695 696 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 694 def create_request @create_request end |
#entry_points ⇒ Array<Google::Apis::CalendarV3::EntryPoint>
Information about individual conference entry points, such as URLs or phone
numbers.
All of them must belong to the same conference.
Either conferenceSolution and at least one entryPoint, or createRequest is
required.
Corresponds to the JSON property entryPoints
703 704 705 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 703 def entry_points @entry_points end |
#notes ⇒ String
Additional notes (such as instructions from the domain administrator, legal
notices) to display to the user. Can contain HTML. The maximum length is 2048
characters. Optional.
Corresponds to the JSON property notes
710 711 712 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 710 def notes @notes end |
#parameters ⇒ Google::Apis::CalendarV3::ConferenceParameters
Additional properties related to a conference. An example would be a solution-
specific setting for enabling video streaming.
Corresponds to the JSON property parameters
716 717 718 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 716 def parameters @parameters end |
#signature ⇒ String
The signature of the conference data.
Generated on server side.
Unset for a conference with a failed create request.
Optional for a conference with a pending create request.
Corresponds to the JSON property signature
724 725 726 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 724 def signature @signature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
731 732 733 734 735 736 737 738 739 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 731 def update!(**args) @conference_id = args[:conference_id] if args.key?(:conference_id) @conference_solution = args[:conference_solution] if args.key?(:conference_solution) @create_request = args[:create_request] if args.key?(:create_request) @entry_points = args[:entry_points] if args.key?(:entry_points) @notes = args[:notes] if args.key?(:notes) @parameters = args[:parameters] if args.key?(:parameters) @signature = args[:signature] if args.key?(:signature) end |