Class: Google::Apis::CalendarV3::ConferenceData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConferenceData

Returns a new instance of ConferenceData.



718
719
720
# File 'lib/google/apis/calendar_v3/classes.rb', line 718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conference_idString

The ID of the conference. Can be used by developers to keep track of conferences, should not be displayed to users. The ID value is formed differently for each conference solution type:

  • eventHangout: ID is not set. (This conference type is deprecated.)
  • eventNamedHangout: ID is the name of the Hangout. (This conference type is deprecated.)
  • hangoutsMeet: ID is the 10-letter meeting code, for example aaa-bbbb-ccc.
  • addOn: ID is defined by the third-party provider. Optional. Corresponds to the JSON property conferenceId

Returns:

  • (String)


669
670
671
# File 'lib/google/apis/calendar_v3/classes.rb', line 669

def conference_id
  @conference_id
end

#conference_solutionGoogle::Apis::CalendarV3::ConferenceSolution

The conference solution, such as Google Meet. Unset for a conference with a failed create request. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property conferenceSolution



677
678
679
# File 'lib/google/apis/calendar_v3/classes.rb', line 677

def conference_solution
  @conference_solution
end

#create_requestGoogle::Apis::CalendarV3::CreateConferenceRequest

A request to generate a new conference and attach it to the event. The data is generated asynchronously. To see whether the data is present check the status field. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property createRequest



686
687
688
# File 'lib/google/apis/calendar_v3/classes.rb', line 686

def create_request
  @create_request
end

#entry_pointsArray<Google::Apis::CalendarV3::EntryPoint>

Information about individual conference entry points, such as URLs or phone numbers. All of them must belong to the same conference. Either conferenceSolution and at least one entryPoint, or createRequest is required. Corresponds to the JSON property entryPoints



695
696
697
# File 'lib/google/apis/calendar_v3/classes.rb', line 695

def entry_points
  @entry_points
end

#notesString

Additional notes (such as instructions from the domain administrator, legal notices) to display to the user. Can contain HTML. The maximum length is 2048 characters. Optional. Corresponds to the JSON property notes

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/calendar_v3/classes.rb', line 702

def notes
  @notes
end

#parametersGoogle::Apis::CalendarV3::ConferenceParameters

Additional properties related to a conference. An example would be a solution- specific setting for enabling video streaming. Corresponds to the JSON property parameters



708
709
710
# File 'lib/google/apis/calendar_v3/classes.rb', line 708

def parameters
  @parameters
end

#signatureString

The signature of the conference data. Generated on server side. Unset for a conference with a failed create request. Optional for a conference with a pending create request. Corresponds to the JSON property signature

Returns:

  • (String)


716
717
718
# File 'lib/google/apis/calendar_v3/classes.rb', line 716

def signature
  @signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



723
724
725
726
727
728
729
730
731
# File 'lib/google/apis/calendar_v3/classes.rb', line 723

def update!(**args)
  @conference_id = args[:conference_id] if args.key?(:conference_id)
  @conference_solution = args[:conference_solution] if args.key?(:conference_solution)
  @create_request = args[:create_request] if args.key?(:create_request)
  @entry_points = args[:entry_points] if args.key?(:entry_points)
  @notes = args[:notes] if args.key?(:notes)
  @parameters = args[:parameters] if args.key?(:parameters)
  @signature = args[:signature] if args.key?(:signature)
end