Class: Google::Apis::CalendarV3::CreateConferenceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateConferenceRequest

Returns a new instance of CreateConferenceRequest.



908
909
910
# File 'lib/google/apis/calendar_v3/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conference_solution_keyGoogle::Apis::CalendarV3::ConferenceSolutionKey

The conference solution, such as Hangouts or Google Meet. Corresponds to the JSON property conferenceSolutionKey



894
895
896
# File 'lib/google/apis/calendar_v3/classes.rb', line 894

def conference_solution_key
  @conference_solution_key
end

#request_idString

The client-generated unique ID for this request. Clients should regenerate this ID for every new request. If an ID provided is the same as for the previous request, the request is ignored. Corresponds to the JSON property requestId

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/calendar_v3/classes.rb', line 901

def request_id
  @request_id
end

#statusGoogle::Apis::CalendarV3::ConferenceRequestStatus

The status of the conference create request. Corresponds to the JSON property status



906
907
908
# File 'lib/google/apis/calendar_v3/classes.rb', line 906

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
917
# File 'lib/google/apis/calendar_v3/classes.rb', line 913

def update!(**args)
  @conference_solution_key = args[:conference_solution_key] if args.key?(:conference_solution_key)
  @request_id = args[:request_id] if args.key?(:request_id)
  @status = args[:status] if args.key?(:status)
end