Class: Google::Apis::CalendarV3::CreateConferenceRequest
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::CreateConferenceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#conference_solution_key ⇒ Google::Apis::CalendarV3::ConferenceSolutionKey
The conference solution, such as Hangouts or Google Meet.
-
#request_id ⇒ String
The client-generated unique ID for this request.
-
#status ⇒ Google::Apis::CalendarV3::ConferenceRequestStatus
The status of the conference create request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateConferenceRequest
constructor
A new instance of CreateConferenceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateConferenceRequest
Returns a new instance of CreateConferenceRequest.
900 901 902 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conference_solution_key ⇒ Google::Apis::CalendarV3::ConferenceSolutionKey
The conference solution, such as Hangouts or Google Meet.
Corresponds to the JSON property conferenceSolutionKey
886 887 888 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 886 def conference_solution_key @conference_solution_key end |
#request_id ⇒ String
The client-generated unique ID for this request.
Clients should regenerate this ID for every new request. If an ID provided is
the same as for the previous request, the request is ignored.
Corresponds to the JSON property requestId
893 894 895 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 893 def request_id @request_id end |
#status ⇒ Google::Apis::CalendarV3::ConferenceRequestStatus
The status of the conference create request.
Corresponds to the JSON property status
898 899 900 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 898 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
905 906 907 908 909 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 905 def update!(**args) @conference_solution_key = args[:conference_solution_key] if args.key?(:conference_solution_key) @request_id = args[:request_id] if args.key?(:request_id) @status = args[:status] if args.key?(:status) end |