Class: Google::Apis::CalendarV3::Event
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Event
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Defined Under Namespace
Classes: Creator, ExtendedProperties, Gadget, Organizer, Reminders, Source
Instance Attribute Summary collapse
-
#anyone_can_add_self ⇒ Boolean
(also: #anyone_can_add_self?)
Whether anyone can invite themselves to the event (deprecated).
-
#attachments ⇒ Array<Google::Apis::CalendarV3::EventAttachment>
File attachments for the event.
-
#attendees ⇒ Array<Google::Apis::CalendarV3::EventAttendee>
The attendees of the event.
-
#attendees_omitted ⇒ Boolean
(also: #attendees_omitted?)
Whether attendees may have been omitted from the event's representation.
-
#birthday_properties ⇒ Google::Apis::CalendarV3::EventBirthdayProperties
Birthday or special event data.
-
#color_id ⇒ String
The color of the event.
-
#conference_data ⇒ Google::Apis::CalendarV3::ConferenceData
The conference-related information, such as details of a Google Meet conference.
-
#created ⇒ DateTime
Creation time of the event (as a RFC3339 timestamp).
-
#creator ⇒ Google::Apis::CalendarV3::Event::Creator
The creator of the event.
-
#description ⇒ String
Description of the event.
-
#end ⇒ Google::Apis::CalendarV3::EventDateTime
The (exclusive) end time of the event.
-
#end_time_unspecified ⇒ Boolean
(also: #end_time_unspecified?)
Whether the end time is actually unspecified.
-
#etag ⇒ String
ETag of the resource.
-
#event_label_id ⇒ String
The ID of the event label assigned to the event.
-
#event_type ⇒ String
Specific type of the event.
-
#extended_properties ⇒ Google::Apis::CalendarV3::Event::ExtendedProperties
Extended properties of the event.
-
#focus_time_properties ⇒ Google::Apis::CalendarV3::EventFocusTimeProperties
Focus Time event data.
-
#gadget ⇒ Google::Apis::CalendarV3::Event::Gadget
A gadget that extends this event.
-
#guests_can_invite_others ⇒ Boolean
(also: #guests_can_invite_others?)
Whether attendees other than the organizer can invite others to the event.
-
#guests_can_modify ⇒ Boolean
(also: #guests_can_modify?)
Whether attendees other than the organizer can modify the event.
-
#guests_can_see_other_guests ⇒ Boolean
(also: #guests_can_see_other_guests?)
Whether attendees other than the organizer can see who the event's attendees are.
-
#hangout_link ⇒ String
An absolute link to the Google Hangout associated with this event.
-
#html_link ⇒ String
An absolute link to this event in the Google Calendar Web UI.
-
#i_cal_uid ⇒ String
Event unique identifier as defined in RFC5545.
-
#id ⇒ String
Opaque identifier of the event.
-
#kind ⇒ String
Type of the resource ("calendar#event").
-
#location ⇒ String
Geographic location of the event as free-form text.
-
#locked ⇒ Boolean
(also: #locked?)
Whether this is a locked event copy where no changes can be made to the main event fields "summary", "description", "location", "start", "end" or " recurrence".
-
#organizer ⇒ Google::Apis::CalendarV3::Event::Organizer
The organizer of the event.
-
#original_start_time ⇒ Google::Apis::CalendarV3::EventDateTime
For an instance of a recurring event, this is the time at which this event would start according to the recurrence data in the recurring event identified by recurringEventId.
-
#out_of_office_properties ⇒ Google::Apis::CalendarV3::EventOutOfOfficeProperties
Out of office event data.
-
#private_copy ⇒ Boolean
(also: #private_copy?)
If set to True, Event propagation is disabled.
-
#recurrence ⇒ Array<String>
List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event, as specified in RFC5545.
-
#recurring_event_id ⇒ String
For an instance of a recurring event, this is the id of the recurring event to which this instance belongs.
-
#reminders ⇒ Google::Apis::CalendarV3::Event::Reminders
Information about the event's reminders for the authenticated user.
-
#sequence ⇒ Fixnum
Sequence number as per iCalendar.
-
#source ⇒ Google::Apis::CalendarV3::Event::Source
Source from which the event was created.
-
#start ⇒ Google::Apis::CalendarV3::EventDateTime
The (inclusive) start time of the event.
-
#status ⇒ String
Status of the event.
-
#summary ⇒ String
Title of the event.
-
#transparency ⇒ String
Whether the event blocks time on the calendar.
-
#updated ⇒ DateTime
Last modification time of the main event data (as a RFC3339 timestamp).
-
#visibility ⇒ String
Visibility of the event.
-
#working_location_properties ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties
Working location event data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Event
constructor
A new instance of Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Event
Returns a new instance of Event.
1422 1423 1424 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anyone_can_add_self ⇒ Boolean Also known as: anyone_can_add_self?
Whether anyone can invite themselves to the event (deprecated). Optional. The
default is False.
Corresponds to the JSON property anyoneCanAddSelf
1081 1082 1083 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1081 def anyone_can_add_self @anyone_can_add_self end |
#attachments ⇒ Array<Google::Apis::CalendarV3::EventAttachment>
File attachments for the event.
In order to modify attachments the supportsAttachments request parameter
should be set to true.
There can be at most 25 attachments per event,
Corresponds to the JSON property attachments
1090 1091 1092 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1090 def @attachments end |
#attendees ⇒ Array<Google::Apis::CalendarV3::EventAttendee>
The attendees of the event. See the Events with attendees guide for more
information on scheduling events with other calendar users. Service accounts
need to use domain-wide delegation of authority to populate the attendee list.
Corresponds to the JSON property attendees
1097 1098 1099 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1097 def attendees @attendees end |
#attendees_omitted ⇒ Boolean Also known as: attendees_omitted?
Whether attendees may have been omitted from the event's representation. When
retrieving an event, this may be due to a restriction specified by the
maxAttendee query parameter. When updating an event, this can be used to only
update the participant's response. Optional. The default is False.
Corresponds to the JSON property attendeesOmitted
1105 1106 1107 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1105 def attendees_omitted @attendees_omitted end |
#birthday_properties ⇒ Google::Apis::CalendarV3::EventBirthdayProperties
Birthday or special event data. Used if eventType is "birthday". Immutable.
Corresponds to the JSON property birthdayProperties
1111 1112 1113 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1111 def birthday_properties @birthday_properties end |
#color_id ⇒ String
The color of the event. This is an ID referring to an entry in the event
section of the colors definition (see the colors endpoint). Optional.
Corresponds to the JSON property colorId
1117 1118 1119 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1117 def color_id @color_id end |
#conference_data ⇒ Google::Apis::CalendarV3::ConferenceData
The conference-related information, such as details of a Google Meet
conference. To create new conference details use the createRequest field. To
persist your changes, remember to set the conferenceDataVersion request
parameter to 1 for all event modification requests. Warning: Reusing Google
Meet conference data across different events can cause access issues and
expose meeting details to unintended users. To help ensure meeting privacy,
always generate a unique conference for each event by using the createRequest
field.
Corresponds to the JSON property conferenceData
1129 1130 1131 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1129 def conference_data @conference_data end |
#created ⇒ DateTime
Creation time of the event (as a RFC3339 timestamp). Read-only.
Corresponds to the JSON property created
1134 1135 1136 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1134 def created @created end |
#creator ⇒ Google::Apis::CalendarV3::Event::Creator
The creator of the event. Read-only.
Corresponds to the JSON property creator
1139 1140 1141 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1139 def creator @creator end |
#description ⇒ String
Description of the event. Can contain HTML. Optional.
Corresponds to the JSON property description
1144 1145 1146 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1144 def description @description end |
#end ⇒ Google::Apis::CalendarV3::EventDateTime
The (exclusive) end time of the event. For a recurring event, this is the end
time of the first instance.
Corresponds to the JSON property end
1150 1151 1152 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1150 def end @end end |
#end_time_unspecified ⇒ Boolean Also known as: end_time_unspecified?
Whether the end time is actually unspecified. An end time is still provided
for compatibility reasons, even if this attribute is set to True. The default
is False.
Corresponds to the JSON property endTimeUnspecified
1157 1158 1159 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1157 def end_time_unspecified @end_time_unspecified end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
1163 1164 1165 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1163 def etag @etag end |
#event_label_id ⇒ String
The ID of the event label assigned to the event. Optional. This refers to the
ID of an entry in the labelProperties.eventLabels property of the calendar (
see the Calendars.get endpoint.)
This property supersedes the index-based colorId property. To set or change
this property, you need to specify eventLabelVersion=1 in the parameters of
the insert, import, update, and patch methods.
Setting an empty string, or not setting this field at all, will remove the
existing label from the event.
Corresponds to the JSON property eventLabelId
1175 1176 1177 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1175 def event_label_id @event_label_id end |
#event_type ⇒ String
Specific type of the event. This cannot be modified after the event is created. Possible values are:
- "birthday" - A special all-day event with an annual recurrence.
- "default" - A regular event or not further specified.
- "focusTime" - A focus-time event.
- "fromGmail" - An event from Gmail. This type of event cannot be created.
- "outOfOffice" - An out-of-office event.
- "workingLocation" - A working location event.
Corresponds to the JSON property
eventType
1187 1188 1189 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1187 def event_type @event_type end |
#extended_properties ⇒ Google::Apis::CalendarV3::Event::ExtendedProperties
Extended properties of the event.
Corresponds to the JSON property extendedProperties
1192 1193 1194 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1192 def extended_properties @extended_properties end |
#focus_time_properties ⇒ Google::Apis::CalendarV3::EventFocusTimeProperties
Focus Time event data. Used if eventType is focusTime.
Corresponds to the JSON property focusTimeProperties
1197 1198 1199 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1197 def focus_time_properties @focus_time_properties end |
#gadget ⇒ Google::Apis::CalendarV3::Event::Gadget
A gadget that extends this event. Gadgets are deprecated; this structure is
instead only used for returning birthday calendar metadata.
Corresponds to the JSON property gadget
1203 1204 1205 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1203 def gadget @gadget end |
#guests_can_invite_others ⇒ Boolean Also known as: guests_can_invite_others?
Whether attendees other than the organizer can invite others to the event.
Optional. The default is True.
Corresponds to the JSON property guestsCanInviteOthers
1209 1210 1211 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1209 def guests_can_invite_others @guests_can_invite_others end |
#guests_can_modify ⇒ Boolean Also known as: guests_can_modify?
Whether attendees other than the organizer can modify the event. Optional. The
default is False.
Corresponds to the JSON property guestsCanModify
1216 1217 1218 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1216 def guests_can_modify @guests_can_modify end |
#guests_can_see_other_guests ⇒ Boolean Also known as: guests_can_see_other_guests?
Whether attendees other than the organizer can see who the event's attendees
are. Optional. The default is True.
Corresponds to the JSON property guestsCanSeeOtherGuests
1223 1224 1225 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1223 def guests_can_see_other_guests @guests_can_see_other_guests end |
#hangout_link ⇒ String
An absolute link to the Google Hangout associated with this event. Read-only.
Corresponds to the JSON property hangoutLink
1229 1230 1231 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1229 def hangout_link @hangout_link end |
#html_link ⇒ String
An absolute link to this event in the Google Calendar Web UI. Read-only.
Corresponds to the JSON property htmlLink
1234 1235 1236 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1234 def html_link @html_link end |
#i_cal_uid ⇒ String
Event unique identifier as defined in RFC5545. It is used to uniquely identify
events accross calendaring systems and must be supplied when importing events
via the import method.
Note that the iCalUID and the id are not identical and only one of them should
be supplied at event creation time. One difference in their semantics is that
in recurring events, all occurrences of one event have different ids while
they all share the same iCalUIDs. To retrieve an event using its iCalUID, call
the events.list method using the iCalUID parameter. To retrieve an event using
its id, call the events.get method.
Corresponds to the JSON property iCalUID
1247 1248 1249 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1247 def i_cal_uid @i_cal_uid end |
#id ⇒ String
Opaque identifier of the event. When creating new single or recurring events, you can specify their IDs. Provided IDs must follow these rules:
- characters allowed in the ID are those used in base32hex encoding, i.e. lowercase letters a-v and digits 0-9, see section 3.1.2 in RFC2938
- the length of the ID must be between 5 and 1024 characters
- the ID must be unique per calendar Due to the globally distributed nature
of the system, we cannot guarantee that ID collisions will be detected at
event creation time. To minimize the risk of collisions we recommend using an
established UUID algorithm such as one described in RFC4122.
If you do not specify an ID, it will be automatically generated by the server.
Note that the icalUID and the id are not identical and only one of them should
be supplied at event creation time. One difference in their semantics is that
in recurring events, all occurrences of one event have different ids while
they all share the same icalUIDs.
Corresponds to the JSON property
id
1265 1266 1267 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1265 def id @id end |
#kind ⇒ String
Type of the resource ("calendar#event").
Corresponds to the JSON property kind
1270 1271 1272 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1270 def kind @kind end |
#location ⇒ String
Geographic location of the event as free-form text. Optional.
Corresponds to the JSON property location
1275 1276 1277 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1275 def location @location end |
#locked ⇒ Boolean Also known as: locked?
Whether this is a locked event copy where no changes can be made to the main
event fields "summary", "description", "location", "start", "end" or "
recurrence". The default is False. Read-Only.
Corresponds to the JSON property locked
1282 1283 1284 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1282 def locked @locked end |
#organizer ⇒ Google::Apis::CalendarV3::Event::Organizer
The organizer of the event. If the organizer is also an attendee, this is
indicated with a separate entry in attendees with the organizer field set to
True. To change the organizer, use the move operation. Read-only, except when
importing an event.
Corresponds to the JSON property organizer
1291 1292 1293 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1291 def organizer @organizer end |
#original_start_time ⇒ Google::Apis::CalendarV3::EventDateTime
For an instance of a recurring event, this is the time at which this event
would start according to the recurrence data in the recurring event identified
by recurringEventId. It uniquely identifies the instance within the recurring
event series even if the instance was moved to a different time. Immutable.
Corresponds to the JSON property originalStartTime
1299 1300 1301 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1299 def original_start_time @original_start_time end |
#out_of_office_properties ⇒ Google::Apis::CalendarV3::EventOutOfOfficeProperties
Out of office event data. Used if eventType is outOfOffice.
Corresponds to the JSON property outOfOfficeProperties
1304 1305 1306 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1304 def out_of_office_properties @out_of_office_properties end |
#private_copy ⇒ Boolean Also known as: private_copy?
If set to True, Event propagation is disabled. Note that it is not the same
thing as Private event properties. Optional. Immutable. The default is False.
Corresponds to the JSON property privateCopy
1310 1311 1312 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1310 def private_copy @private_copy end |
#recurrence ⇒ Array<String>
List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event, as
specified in RFC5545. Note that DTSTART and DTEND lines are not allowed in
this field; event start and end times are specified in the start and end
fields. This field is omitted for single events or instances of recurring
events.
Corresponds to the JSON property recurrence
1320 1321 1322 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1320 def recurrence @recurrence end |
#recurring_event_id ⇒ String
For an instance of a recurring event, this is the id of the recurring event to
which this instance belongs. Immutable.
Corresponds to the JSON property recurringEventId
1326 1327 1328 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1326 def recurring_event_id @recurring_event_id end |
#reminders ⇒ Google::Apis::CalendarV3::Event::Reminders
Information about the event's reminders for the authenticated user. Note that
changing reminders does not also change the updated property of the enclosing
event.
Corresponds to the JSON property reminders
1333 1334 1335 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1333 def reminders @reminders end |
#sequence ⇒ Fixnum
Sequence number as per iCalendar.
Corresponds to the JSON property sequence
1338 1339 1340 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1338 def sequence @sequence end |
#source ⇒ Google::Apis::CalendarV3::Event::Source
Source from which the event was created. For example, a web page, an email
message or any document identifiable by an URL with HTTP or HTTPS scheme. Can
only be seen or modified by the creator of the event.
Corresponds to the JSON property source
1345 1346 1347 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1345 def source @source end |
#start ⇒ Google::Apis::CalendarV3::EventDateTime
The (inclusive) start time of the event. For a recurring event, this is the
start time of the first instance.
Corresponds to the JSON property start
1351 1352 1353 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1351 def start @start end |
#status ⇒ String
Status of the event. Optional. Possible values are:
- "confirmed" - The event is confirmed. This is the default status.
- "tentative" - The event is tentatively confirmed.
"cancelled" - The event is cancelled (deleted). The list method returns cancelled events only on incremental sync (when syncToken or updatedMin are specified) or if the showDeleted flag is set to true. The get method always returns them. A cancelled status represents two different states depending on the event type:
Cancelled exceptions of an uncancelled recurring event indicate that this instance should no longer be presented to the user. Clients should store these events for the lifetime of the parent recurring event. Cancelled exceptions are only guaranteed to have values for the id, recurringEventId and originalStartTime fields populated. The other fields might be empty.
All other cancelled events represent deleted events. Clients should remove their locally synced copies. Such cancelled events will eventually disappear, so do not rely on them being available indefinitely. Deleted events are only guaranteed to have the id field populated. On the organizer's calendar, cancelled events continue to expose event details ( summary, location, etc.) so that they can be restored (undeleted). Similarly, the events to which the user was invited and that they manually removed continue to provide details. However, incremental sync requests with showDeleted set to false will not return these details. If an event changes its organizer (for example via the move operation) and the original organizer is not on the attendee list, it will leave behind a cancelled event where only the id field is guaranteed to be populated. Corresponds to the JSON property
status
1382 1383 1384 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1382 def status @status end |
#summary ⇒ String
Title of the event.
Corresponds to the JSON property summary
1387 1388 1389 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1387 def summary @summary end |
#transparency ⇒ String
Whether the event blocks time on the calendar. Optional. Possible values are:
- "opaque" - Default value. The event does block time on the calendar. This is equivalent to setting Show me as to Busy in the Calendar UI.
- "transparent" - The event does not block time on the calendar. This is
equivalent to setting Show me as to Available in the Calendar UI.
Corresponds to the JSON property
transparency
1396 1397 1398 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1396 def transparency @transparency end |
#updated ⇒ DateTime
Last modification time of the main event data (as a RFC3339 timestamp).
Updating event reminders will not cause this to change. Read-only.
Corresponds to the JSON property updated
1402 1403 1404 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1402 def updated @updated end |
#visibility ⇒ String
Visibility of the event. Optional. Possible values are:
- "default" - Uses the default visibility for events on the calendar. This is the default value.
- "public" - The event is public and event details are visible to all readers of the calendar.
- "private" - The event is private and only event attendees may view event details.
- "confidential" - The event is private. This value is provided for
compatibility reasons.
Corresponds to the JSON property
visibility
1415 1416 1417 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1415 def visibility @visibility end |
#working_location_properties ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties
Working location event data.
Corresponds to the JSON property workingLocationProperties
1420 1421 1422 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1420 def working_location_properties @working_location_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1427 def update!(**args) @anyone_can_add_self = args[:anyone_can_add_self] if args.key?(:anyone_can_add_self) @attachments = args[:attachments] if args.key?(:attachments) @attendees = args[:attendees] if args.key?(:attendees) @attendees_omitted = args[:attendees_omitted] if args.key?(:attendees_omitted) @birthday_properties = args[:birthday_properties] if args.key?(:birthday_properties) @color_id = args[:color_id] if args.key?(:color_id) @conference_data = args[:conference_data] if args.key?(:conference_data) @created = args[:created] if args.key?(:created) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @end = args[:end] if args.key?(:end) @end_time_unspecified = args[:end_time_unspecified] if args.key?(:end_time_unspecified) @etag = args[:etag] if args.key?(:etag) @event_label_id = args[:event_label_id] if args.key?(:event_label_id) @event_type = args[:event_type] if args.key?(:event_type) @extended_properties = args[:extended_properties] if args.key?(:extended_properties) @focus_time_properties = args[:focus_time_properties] if args.key?(:focus_time_properties) @gadget = args[:gadget] if args.key?(:gadget) @guests_can_invite_others = args[:guests_can_invite_others] if args.key?(:guests_can_invite_others) @guests_can_modify = args[:guests_can_modify] if args.key?(:guests_can_modify) @guests_can_see_other_guests = args[:guests_can_see_other_guests] if args.key?(:guests_can_see_other_guests) @hangout_link = args[:hangout_link] if args.key?(:hangout_link) @html_link = args[:html_link] if args.key?(:html_link) @i_cal_uid = args[:i_cal_uid] if args.key?(:i_cal_uid) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location = args[:location] if args.key?(:location) @locked = args[:locked] if args.key?(:locked) @organizer = args[:organizer] if args.key?(:organizer) @original_start_time = args[:original_start_time] if args.key?(:original_start_time) @out_of_office_properties = args[:out_of_office_properties] if args.key?(:out_of_office_properties) @private_copy = args[:private_copy] if args.key?(:private_copy) @recurrence = args[:recurrence] if args.key?(:recurrence) @recurring_event_id = args[:recurring_event_id] if args.key?(:recurring_event_id) @reminders = args[:reminders] if args.key?(:reminders) @sequence = args[:sequence] if args.key?(:sequence) @source = args[:source] if args.key?(:source) @start = args[:start] if args.key?(:start) @status = args[:status] if args.key?(:status) @summary = args[:summary] if args.key?(:summary) @transparency = args[:transparency] if args.key?(:transparency) @updated = args[:updated] if args.key?(:updated) @visibility = args[:visibility] if args.key?(:visibility) @working_location_properties = args[:working_location_properties] if args.key?(:working_location_properties) end |