Class: Google::Apis::CalendarV3::Event

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Defined Under Namespace

Classes: Creator, ExtendedProperties, Gadget, Organizer, Reminders, Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Event

Returns a new instance of Event.



1398
1399
1400
# File 'lib/google/apis/calendar_v3/classes.rb', line 1398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anyone_can_add_selfBoolean Also known as: anyone_can_add_self?

Whether anyone can invite themselves to the event (deprecated). Optional. The default is False. Corresponds to the JSON property anyoneCanAddSelf

Returns:

  • (Boolean)


1073
1074
1075
# File 'lib/google/apis/calendar_v3/classes.rb', line 1073

def anyone_can_add_self
  @anyone_can_add_self
end

#attachmentsArray<Google::Apis::CalendarV3::EventAttachment>

File attachments for the event. In order to modify attachments the supportsAttachments request parameter should be set to true. There can be at most 25 attachments per event, Corresponds to the JSON property attachments



1082
1083
1084
# File 'lib/google/apis/calendar_v3/classes.rb', line 1082

def attachments
  @attachments
end

#attendeesArray<Google::Apis::CalendarV3::EventAttendee>

The attendees of the event. See the Events with attendees guide for more information on scheduling events with other calendar users. Service accounts need to use domain-wide delegation of authority to populate the attendee list. Corresponds to the JSON property attendees



1089
1090
1091
# File 'lib/google/apis/calendar_v3/classes.rb', line 1089

def attendees
  @attendees
end

#attendees_omittedBoolean Also known as: attendees_omitted?

Whether attendees may have been omitted from the event's representation. When retrieving an event, this may be due to a restriction specified by the maxAttendee query parameter. When updating an event, this can be used to only update the participant's response. Optional. The default is False. Corresponds to the JSON property attendeesOmitted

Returns:

  • (Boolean)


1097
1098
1099
# File 'lib/google/apis/calendar_v3/classes.rb', line 1097

def attendees_omitted
  @attendees_omitted
end

#birthday_propertiesGoogle::Apis::CalendarV3::EventBirthdayProperties

Birthday or special event data. Used if eventType is "birthday". Immutable. Corresponds to the JSON property birthdayProperties



1103
1104
1105
# File 'lib/google/apis/calendar_v3/classes.rb', line 1103

def birthday_properties
  @birthday_properties
end

#color_idString

The color of the event. This is an ID referring to an entry in the event section of the colors definition (see the colors endpoint). Optional. Corresponds to the JSON property colorId

Returns:

  • (String)


1109
1110
1111
# File 'lib/google/apis/calendar_v3/classes.rb', line 1109

def color_id
  @color_id
end

#conference_dataGoogle::Apis::CalendarV3::ConferenceData

The conference-related information, such as details of a Google Meet conference. To create new conference details use the createRequest field. To persist your changes, remember to set the conferenceDataVersion request parameter to 1 for all event modification requests. Corresponds to the JSON property conferenceData



1117
1118
1119
# File 'lib/google/apis/calendar_v3/classes.rb', line 1117

def conference_data
  @conference_data
end

#createdDateTime

Creation time of the event (as a RFC3339 timestamp). Read-only. Corresponds to the JSON property created

Returns:

  • (DateTime)


1122
1123
1124
# File 'lib/google/apis/calendar_v3/classes.rb', line 1122

def created
  @created
end

#creatorGoogle::Apis::CalendarV3::Event::Creator

The creator of the event. Read-only. Corresponds to the JSON property creator



1127
1128
1129
# File 'lib/google/apis/calendar_v3/classes.rb', line 1127

def creator
  @creator
end

#descriptionString

Description of the event. Can contain HTML. Optional. Corresponds to the JSON property description

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/calendar_v3/classes.rb', line 1132

def description
  @description
end

#endGoogle::Apis::CalendarV3::EventDateTime

The (exclusive) end time of the event. For a recurring event, this is the end time of the first instance. Corresponds to the JSON property end



1138
1139
1140
# File 'lib/google/apis/calendar_v3/classes.rb', line 1138

def end
  @end
end

#end_time_unspecifiedBoolean Also known as: end_time_unspecified?

Whether the end time is actually unspecified. An end time is still provided for compatibility reasons, even if this attribute is set to True. The default is False. Corresponds to the JSON property endTimeUnspecified

Returns:

  • (Boolean)


1145
1146
1147
# File 'lib/google/apis/calendar_v3/classes.rb', line 1145

def end_time_unspecified
  @end_time_unspecified
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


1151
1152
1153
# File 'lib/google/apis/calendar_v3/classes.rb', line 1151

def etag
  @etag
end

#event_typeString

Specific type of the event. This cannot be modified after the event is created. Possible values are:

  • "birthday" - A special all-day event with an annual recurrence.
  • "default" - A regular event or not further specified.
  • "focusTime" - A focus-time event.
  • "fromGmail" - An event from Gmail. This type of event cannot be created.
  • "outOfOffice" - An out-of-office event.
  • "workingLocation" - A working location event. Corresponds to the JSON property eventType

Returns:

  • (String)


1163
1164
1165
# File 'lib/google/apis/calendar_v3/classes.rb', line 1163

def event_type
  @event_type
end

#extended_propertiesGoogle::Apis::CalendarV3::Event::ExtendedProperties

Extended properties of the event. Corresponds to the JSON property extendedProperties



1168
1169
1170
# File 'lib/google/apis/calendar_v3/classes.rb', line 1168

def extended_properties
  @extended_properties
end

#focus_time_propertiesGoogle::Apis::CalendarV3::EventFocusTimeProperties

Focus Time event data. Used if eventType is focusTime. Corresponds to the JSON property focusTimeProperties



1173
1174
1175
# File 'lib/google/apis/calendar_v3/classes.rb', line 1173

def focus_time_properties
  @focus_time_properties
end

#gadgetGoogle::Apis::CalendarV3::Event::Gadget

A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata. Corresponds to the JSON property gadget



1179
1180
1181
# File 'lib/google/apis/calendar_v3/classes.rb', line 1179

def gadget
  @gadget
end

#guests_can_invite_othersBoolean Also known as: guests_can_invite_others?

Whether attendees other than the organizer can invite others to the event. Optional. The default is True. Corresponds to the JSON property guestsCanInviteOthers

Returns:

  • (Boolean)


1185
1186
1187
# File 'lib/google/apis/calendar_v3/classes.rb', line 1185

def guests_can_invite_others
  @guests_can_invite_others
end

#guests_can_modifyBoolean Also known as: guests_can_modify?

Whether attendees other than the organizer can modify the event. Optional. The default is False. Corresponds to the JSON property guestsCanModify

Returns:

  • (Boolean)


1192
1193
1194
# File 'lib/google/apis/calendar_v3/classes.rb', line 1192

def guests_can_modify
  @guests_can_modify
end

#guests_can_see_other_guestsBoolean Also known as: guests_can_see_other_guests?

Whether attendees other than the organizer can see who the event's attendees are. Optional. The default is True. Corresponds to the JSON property guestsCanSeeOtherGuests

Returns:

  • (Boolean)


1199
1200
1201
# File 'lib/google/apis/calendar_v3/classes.rb', line 1199

def guests_can_see_other_guests
  @guests_can_see_other_guests
end

An absolute link to the Google Hangout associated with this event. Read-only. Corresponds to the JSON property hangoutLink

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/calendar_v3/classes.rb', line 1205

def hangout_link
  @hangout_link
end

An absolute link to this event in the Google Calendar Web UI. Read-only. Corresponds to the JSON property htmlLink

Returns:

  • (String)


1210
1211
1212
# File 'lib/google/apis/calendar_v3/classes.rb', line 1210

def html_link
  @html_link
end

#i_cal_uidString

Event unique identifier as defined in RFC5545. It is used to uniquely identify events accross calendaring systems and must be supplied when importing events via the import method. Note that the iCalUID and the id are not identical and only one of them should be supplied at event creation time. One difference in their semantics is that in recurring events, all occurrences of one event have different ids while they all share the same iCalUIDs. To retrieve an event using its iCalUID, call the events.list method using the iCalUID parameter. To retrieve an event using its id, call the events.get method. Corresponds to the JSON property iCalUID

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/calendar_v3/classes.rb', line 1223

def i_cal_uid
  @i_cal_uid
end

#idString

Opaque identifier of the event. When creating new single or recurring events, you can specify their IDs. Provided IDs must follow these rules:

  • characters allowed in the ID are those used in base32hex encoding, i.e. lowercase letters a-v and digits 0-9, see section 3.1.2 in RFC2938
  • the length of the ID must be between 5 and 1024 characters
  • the ID must be unique per calendar Due to the globally distributed nature of the system, we cannot guarantee that ID collisions will be detected at event creation time. To minimize the risk of collisions we recommend using an established UUID algorithm such as one described in RFC4122. If you do not specify an ID, it will be automatically generated by the server. Note that the icalUID and the id are not identical and only one of them should be supplied at event creation time. One difference in their semantics is that in recurring events, all occurrences of one event have different ids while they all share the same icalUIDs. Corresponds to the JSON property id

Returns:

  • (String)


1241
1242
1243
# File 'lib/google/apis/calendar_v3/classes.rb', line 1241

def id
  @id
end

#kindString

Type of the resource ("calendar#event"). Corresponds to the JSON property kind

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/calendar_v3/classes.rb', line 1246

def kind
  @kind
end

#locationString

Geographic location of the event as free-form text. Optional. Corresponds to the JSON property location

Returns:

  • (String)


1251
1252
1253
# File 'lib/google/apis/calendar_v3/classes.rb', line 1251

def location
  @location
end

#lockedBoolean Also known as: locked?

Whether this is a locked event copy where no changes can be made to the main event fields "summary", "description", "location", "start", "end" or " recurrence". The default is False. Read-Only. Corresponds to the JSON property locked

Returns:

  • (Boolean)


1258
1259
1260
# File 'lib/google/apis/calendar_v3/classes.rb', line 1258

def locked
  @locked
end

#organizerGoogle::Apis::CalendarV3::Event::Organizer

The organizer of the event. If the organizer is also an attendee, this is indicated with a separate entry in attendees with the organizer field set to True. To change the organizer, use the move operation. Read-only, except when importing an event. Corresponds to the JSON property organizer



1267
1268
1269
# File 'lib/google/apis/calendar_v3/classes.rb', line 1267

def organizer
  @organizer
end

#original_start_timeGoogle::Apis::CalendarV3::EventDateTime

For an instance of a recurring event, this is the time at which this event would start according to the recurrence data in the recurring event identified by recurringEventId. It uniquely identifies the instance within the recurring event series even if the instance was moved to a different time. Immutable. Corresponds to the JSON property originalStartTime



1275
1276
1277
# File 'lib/google/apis/calendar_v3/classes.rb', line 1275

def original_start_time
  @original_start_time
end

#out_of_office_propertiesGoogle::Apis::CalendarV3::EventOutOfOfficeProperties

Out of office event data. Used if eventType is outOfOffice. Corresponds to the JSON property outOfOfficeProperties



1280
1281
1282
# File 'lib/google/apis/calendar_v3/classes.rb', line 1280

def out_of_office_properties
  @out_of_office_properties
end

#private_copyBoolean Also known as: private_copy?

If set to True, Event propagation is disabled. Note that it is not the same thing as Private event properties. Optional. Immutable. The default is False. Corresponds to the JSON property privateCopy

Returns:

  • (Boolean)


1286
1287
1288
# File 'lib/google/apis/calendar_v3/classes.rb', line 1286

def private_copy
  @private_copy
end

#recurrenceArray<String>

List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event, as specified in RFC5545. Note that DTSTART and DTEND lines are not allowed in this field; event start and end times are specified in the start and end fields. This field is omitted for single events or instances of recurring events. Corresponds to the JSON property recurrence

Returns:

  • (Array<String>)


1296
1297
1298
# File 'lib/google/apis/calendar_v3/classes.rb', line 1296

def recurrence
  @recurrence
end

#recurring_event_idString

For an instance of a recurring event, this is the id of the recurring event to which this instance belongs. Immutable. Corresponds to the JSON property recurringEventId

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/calendar_v3/classes.rb', line 1302

def recurring_event_id
  @recurring_event_id
end

#remindersGoogle::Apis::CalendarV3::Event::Reminders

Information about the event's reminders for the authenticated user. Note that changing reminders does not also change the updated property of the enclosing event. Corresponds to the JSON property reminders



1309
1310
1311
# File 'lib/google/apis/calendar_v3/classes.rb', line 1309

def reminders
  @reminders
end

#sequenceFixnum

Sequence number as per iCalendar. Corresponds to the JSON property sequence

Returns:

  • (Fixnum)


1314
1315
1316
# File 'lib/google/apis/calendar_v3/classes.rb', line 1314

def sequence
  @sequence
end

#sourceGoogle::Apis::CalendarV3::Event::Source

Source from which the event was created. For example, a web page, an email message or any document identifiable by an URL with HTTP or HTTPS scheme. Can only be seen or modified by the creator of the event. Corresponds to the JSON property source



1321
1322
1323
# File 'lib/google/apis/calendar_v3/classes.rb', line 1321

def source
  @source
end

#startGoogle::Apis::CalendarV3::EventDateTime

The (inclusive) start time of the event. For a recurring event, this is the start time of the first instance. Corresponds to the JSON property start



1327
1328
1329
# File 'lib/google/apis/calendar_v3/classes.rb', line 1327

def start
  @start
end

#statusString

Status of the event. Optional. Possible values are:

  • "confirmed" - The event is confirmed. This is the default status.
  • "tentative" - The event is tentatively confirmed.
  • "cancelled" - The event is cancelled (deleted). The list method returns cancelled events only on incremental sync (when syncToken or updatedMin are specified) or if the showDeleted flag is set to true. The get method always returns them. A cancelled status represents two different states depending on the event type:

  • Cancelled exceptions of an uncancelled recurring event indicate that this instance should no longer be presented to the user. Clients should store these events for the lifetime of the parent recurring event. Cancelled exceptions are only guaranteed to have values for the id, recurringEventId and originalStartTime fields populated. The other fields might be empty.

  • All other cancelled events represent deleted events. Clients should remove their locally synced copies. Such cancelled events will eventually disappear, so do not rely on them being available indefinitely. Deleted events are only guaranteed to have the id field populated. On the organizer's calendar, cancelled events continue to expose event details ( summary, location, etc.) so that they can be restored (undeleted). Similarly, the events to which the user was invited and that they manually removed continue to provide details. However, incremental sync requests with showDeleted set to false will not return these details. If an event changes its organizer (for example via the move operation) and the original organizer is not on the attendee list, it will leave behind a cancelled event where only the id field is guaranteed to be populated. Corresponds to the JSON property status

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/calendar_v3/classes.rb', line 1358

def status
  @status
end

#summaryString

Title of the event. Corresponds to the JSON property summary

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/calendar_v3/classes.rb', line 1363

def summary
  @summary
end

#transparencyString

Whether the event blocks time on the calendar. Optional. Possible values are:

  • "opaque" - Default value. The event does block time on the calendar. This is equivalent to setting Show me as to Busy in the Calendar UI.
  • "transparent" - The event does not block time on the calendar. This is equivalent to setting Show me as to Available in the Calendar UI. Corresponds to the JSON property transparency

Returns:

  • (String)


1372
1373
1374
# File 'lib/google/apis/calendar_v3/classes.rb', line 1372

def transparency
  @transparency
end

#updatedDateTime

Last modification time of the main event data (as a RFC3339 timestamp). Updating event reminders will not cause this to change. Read-only. Corresponds to the JSON property updated

Returns:

  • (DateTime)


1378
1379
1380
# File 'lib/google/apis/calendar_v3/classes.rb', line 1378

def updated
  @updated
end

#visibilityString

Visibility of the event. Optional. Possible values are:

  • "default" - Uses the default visibility for events on the calendar. This is the default value.
  • "public" - The event is public and event details are visible to all readers of the calendar.
  • "private" - The event is private and only event attendees may view event details.
  • "confidential" - The event is private. This value is provided for compatibility reasons. Corresponds to the JSON property visibility

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/calendar_v3/classes.rb', line 1391

def visibility
  @visibility
end

#working_location_propertiesGoogle::Apis::CalendarV3::EventWorkingLocationProperties

Working location event data. Corresponds to the JSON property workingLocationProperties



1396
1397
1398
# File 'lib/google/apis/calendar_v3/classes.rb', line 1396

def working_location_properties
  @working_location_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
# File 'lib/google/apis/calendar_v3/classes.rb', line 1403

def update!(**args)
  @anyone_can_add_self = args[:anyone_can_add_self] if args.key?(:anyone_can_add_self)
  @attachments = args[:attachments] if args.key?(:attachments)
  @attendees = args[:attendees] if args.key?(:attendees)
  @attendees_omitted = args[:attendees_omitted] if args.key?(:attendees_omitted)
  @birthday_properties = args[:birthday_properties] if args.key?(:birthday_properties)
  @color_id = args[:color_id] if args.key?(:color_id)
  @conference_data = args[:conference_data] if args.key?(:conference_data)
  @created = args[:created] if args.key?(:created)
  @creator = args[:creator] if args.key?(:creator)
  @description = args[:description] if args.key?(:description)
  @end = args[:end] if args.key?(:end)
  @end_time_unspecified = args[:end_time_unspecified] if args.key?(:end_time_unspecified)
  @etag = args[:etag] if args.key?(:etag)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_properties = args[:extended_properties] if args.key?(:extended_properties)
  @focus_time_properties = args[:focus_time_properties] if args.key?(:focus_time_properties)
  @gadget = args[:gadget] if args.key?(:gadget)
  @guests_can_invite_others = args[:guests_can_invite_others] if args.key?(:guests_can_invite_others)
  @guests_can_modify = args[:guests_can_modify] if args.key?(:guests_can_modify)
  @guests_can_see_other_guests = args[:guests_can_see_other_guests] if args.key?(:guests_can_see_other_guests)
  @hangout_link = args[:hangout_link] if args.key?(:hangout_link)
  @html_link = args[:html_link] if args.key?(:html_link)
  @i_cal_uid = args[:i_cal_uid] if args.key?(:i_cal_uid)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location = args[:location] if args.key?(:location)
  @locked = args[:locked] if args.key?(:locked)
  @organizer = args[:organizer] if args.key?(:organizer)
  @original_start_time = args[:original_start_time] if args.key?(:original_start_time)
  @out_of_office_properties = args[:out_of_office_properties] if args.key?(:out_of_office_properties)
  @private_copy = args[:private_copy] if args.key?(:private_copy)
  @recurrence = args[:recurrence] if args.key?(:recurrence)
  @recurring_event_id = args[:recurring_event_id] if args.key?(:recurring_event_id)
  @reminders = args[:reminders] if args.key?(:reminders)
  @sequence = args[:sequence] if args.key?(:sequence)
  @source = args[:source] if args.key?(:source)
  @start = args[:start] if args.key?(:start)
  @status = args[:status] if args.key?(:status)
  @summary = args[:summary] if args.key?(:summary)
  @transparency = args[:transparency] if args.key?(:transparency)
  @updated = args[:updated] if args.key?(:updated)
  @visibility = args[:visibility] if args.key?(:visibility)
  @working_location_properties = args[:working_location_properties] if args.key?(:working_location_properties)
end