Class: Google::Apis::CalendarV3::Event::ExtendedProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

Extended properties of the event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtendedProperties

Returns a new instance of ExtendedProperties.



1504
1505
1506
# File 'lib/google/apis/calendar_v3/classes.rb', line 1504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#privateHash<String,String>

Properties that are private to the copy of the event that appears on this calendar. Corresponds to the JSON property private

Returns:

  • (Hash<String,String>)


1496
1497
1498
# File 'lib/google/apis/calendar_v3/classes.rb', line 1496

def private
  @private
end

#sharedHash<String,String>

Properties that are shared between copies of the event on other attendees' calendars. Corresponds to the JSON property shared

Returns:

  • (Hash<String,String>)


1502
1503
1504
# File 'lib/google/apis/calendar_v3/classes.rb', line 1502

def shared
  @shared
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1509
1510
1511
1512
# File 'lib/google/apis/calendar_v3/classes.rb', line 1509

def update!(**args)
  @private = args[:private] if args.key?(:private)
  @shared = args[:shared] if args.key?(:shared)
end