Class: Google::Apis::CalendarV3::Event::Gadget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Gadget

Returns a new instance of Gadget.



1568
1569
1570
# File 'lib/google/apis/calendar_v3/classes.rb', line 1568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_modeString

The gadget's display mode. Deprecated. Possible values are:

  • "icon" - The gadget displays next to the event's title in the calendar view.
  • "chip" - The gadget displays when the event is clicked. Corresponds to the JSON property display

Returns:

  • (String)


1529
1530
1531
# File 'lib/google/apis/calendar_v3/classes.rb', line 1529

def display_mode
  @display_mode
end

#heightFixnum

The gadget's height in pixels. The height must be an integer greater than 0. Optional. Deprecated. Corresponds to the JSON property height

Returns:

  • (Fixnum)


1535
1536
1537
# File 'lib/google/apis/calendar_v3/classes.rb', line 1535

def height
  @height
end

The gadget's icon URL. The URL scheme must be HTTPS. Deprecated. Corresponds to the JSON property iconLink

Returns:

  • (String)


1540
1541
1542
# File 'lib/google/apis/calendar_v3/classes.rb', line 1540

def icon_link
  @icon_link
end

The gadget's URL. The URL scheme must be HTTPS. Deprecated. Corresponds to the JSON property link

Returns:

  • (String)


1545
1546
1547
# File 'lib/google/apis/calendar_v3/classes.rb', line 1545

def link
  @link
end

#preferencesHash<String,String>

Preferences. Corresponds to the JSON property preferences

Returns:

  • (Hash<String,String>)


1550
1551
1552
# File 'lib/google/apis/calendar_v3/classes.rb', line 1550

def preferences
  @preferences
end

#titleString

The gadget's title. Deprecated. Corresponds to the JSON property title

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/calendar_v3/classes.rb', line 1555

def title
  @title
end

#typeString

The gadget's type. Deprecated. Corresponds to the JSON property type

Returns:

  • (String)


1560
1561
1562
# File 'lib/google/apis/calendar_v3/classes.rb', line 1560

def type
  @type
end

#widthFixnum

The gadget's width in pixels. The width must be an integer greater than 0. Optional. Deprecated. Corresponds to the JSON property width

Returns:

  • (Fixnum)


1566
1567
1568
# File 'lib/google/apis/calendar_v3/classes.rb', line 1566

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
# File 'lib/google/apis/calendar_v3/classes.rb', line 1573

def update!(**args)
  @display_mode = args[:display_mode] if args.key?(:display_mode)
  @height = args[:height] if args.key?(:height)
  @icon_link = args[:icon_link] if args.key?(:icon_link)
  @link = args[:link] if args.key?(:link)
  @preferences = args[:preferences] if args.key?(:preferences)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @width = args[:width] if args.key?(:width)
end