Class: Google::Apis::CalendarV3::Event::Gadget
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Event::Gadget
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
Instance Attribute Summary collapse
-
#display_mode ⇒ String
The gadget's display mode.
-
#height ⇒ Fixnum
The gadget's height in pixels.
-
#icon_link ⇒ String
The gadget's icon URL.
-
#link ⇒ String
The gadget's URL.
-
#preferences ⇒ Hash<String,String>
Preferences.
-
#title ⇒ String
The gadget's title.
-
#type ⇒ String
The gadget's type.
-
#width ⇒ Fixnum
The gadget's width in pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Gadget
constructor
A new instance of Gadget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Gadget
Returns a new instance of Gadget.
1564 1565 1566 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_mode ⇒ String
The gadget's display mode. Deprecated. Possible values are:
- "icon" - The gadget displays next to the event's title in the calendar view.
- "chip" - The gadget displays when the event is clicked.
Corresponds to the JSON property
display
1525 1526 1527 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1525 def display_mode @display_mode end |
#height ⇒ Fixnum
The gadget's height in pixels. The height must be an integer greater than 0.
Optional. Deprecated.
Corresponds to the JSON property height
1531 1532 1533 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1531 def height @height end |
#icon_link ⇒ String
The gadget's icon URL. The URL scheme must be HTTPS. Deprecated.
Corresponds to the JSON property iconLink
1536 1537 1538 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1536 def icon_link @icon_link end |
#link ⇒ String
The gadget's URL. The URL scheme must be HTTPS. Deprecated.
Corresponds to the JSON property link
1541 1542 1543 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1541 def link @link end |
#preferences ⇒ Hash<String,String>
Preferences.
Corresponds to the JSON property preferences
1546 1547 1548 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1546 def preferences @preferences end |
#title ⇒ String
The gadget's title. Deprecated.
Corresponds to the JSON property title
1551 1552 1553 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1551 def title @title end |
#type ⇒ String
The gadget's type. Deprecated.
Corresponds to the JSON property type
1556 1557 1558 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1556 def type @type end |
#width ⇒ Fixnum
The gadget's width in pixels. The width must be an integer greater than 0.
Optional. Deprecated.
Corresponds to the JSON property width
1562 1563 1564 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1562 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1569 def update!(**args) @display_mode = args[:display_mode] if args.key?(:display_mode) @height = args[:height] if args.key?(:height) @icon_link = args[:icon_link] if args.key?(:icon_link) @link = args[:link] if args.key?(:link) @preferences = args[:preferences] if args.key?(:preferences) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) @width = args[:width] if args.key?(:width) end |