Class: Google::Apis::CalendarV3::Event::Reminders

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

Information about the event's reminders for the authenticated user. Note that changing reminders does not also change the updated property of the enclosing event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reminders

Returns a new instance of Reminders.



1668
1669
1670
# File 'lib/google/apis/calendar_v3/classes.rb', line 1668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#overridesArray<Google::Apis::CalendarV3::EventReminder>

If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event. The maximum number of override reminders is 5. Corresponds to the JSON property overrides



1660
1661
1662
# File 'lib/google/apis/calendar_v3/classes.rb', line 1660

def overrides
  @overrides
end

#use_defaultBoolean Also known as: use_default?

Whether the default reminders of the calendar apply to the event. Corresponds to the JSON property useDefault

Returns:

  • (Boolean)


1665
1666
1667
# File 'lib/google/apis/calendar_v3/classes.rb', line 1665

def use_default
  @use_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1673
1674
1675
1676
# File 'lib/google/apis/calendar_v3/classes.rb', line 1673

def update!(**args)
  @overrides = args[:overrides] if args.key?(:overrides)
  @use_default = args[:use_default] if args.key?(:use_default)
end