Class: Google::Apis::CalendarV3::Event::Reminders
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Event::Reminders
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
Information about the event's reminders for the authenticated user. Note that changing reminders does not also change the updated property of the enclosing event.
Instance Attribute Summary collapse
-
#overrides ⇒ Array<Google::Apis::CalendarV3::EventReminder>
If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event.
-
#use_default ⇒ Boolean
(also: #use_default?)
Whether the default reminders of the calendar apply to the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reminders
constructor
A new instance of Reminders.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reminders
Returns a new instance of Reminders.
1647 1648 1649 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#overrides ⇒ Array<Google::Apis::CalendarV3::EventReminder>
If the event doesn't use the default reminders, this lists the reminders
specific to the event, or, if not set, indicates that no reminders are set for
this event. The maximum number of override reminders is 5.
Corresponds to the JSON property overrides
1639 1640 1641 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1639 def overrides @overrides end |
#use_default ⇒ Boolean Also known as: use_default?
Whether the default reminders of the calendar apply to the event.
Corresponds to the JSON property useDefault
1644 1645 1646 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1644 def use_default @use_default end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1652 1653 1654 1655 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1652 def update!(**args) @overrides = args[:overrides] if args.key?(:overrides) @use_default = args[:use_default] if args.key?(:use_default) end |