Class: Google::Apis::CalendarV3::Event::Reminders
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Event::Reminders
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
Information about the event's reminders for the authenticated user. Note that changing reminders does not also change the updated property of the enclosing event.
Instance Attribute Summary collapse
-
#overrides ⇒ Array<Google::Apis::CalendarV3::EventReminder>
If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event.
-
#use_default ⇒ Boolean
(also: #use_default?)
Whether the default reminders of the calendar apply to the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reminders
constructor
A new instance of Reminders.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reminders
Returns a new instance of Reminders.
1643 1644 1645 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#overrides ⇒ Array<Google::Apis::CalendarV3::EventReminder>
If the event doesn't use the default reminders, this lists the reminders
specific to the event, or, if not set, indicates that no reminders are set for
this event. The maximum number of override reminders is 5.
Corresponds to the JSON property overrides
1635 1636 1637 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1635 def overrides @overrides end |
#use_default ⇒ Boolean Also known as: use_default?
Whether the default reminders of the calendar apply to the event.
Corresponds to the JSON property useDefault
1640 1641 1642 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1640 def use_default @use_default end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1648 1649 1650 1651 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1648 def update!(**args) @overrides = args[:overrides] if args.key?(:overrides) @use_default = args[:use_default] if args.key?(:use_default) end |