Class: Google::Apis::CalendarV3::Event::Source
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Event::Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Overview
Source from which the event was created. For example, a web page, an email message or any document identifiable by an URL with HTTP or HTTPS scheme. Can only be seen or modified by the creator of the event.
Instance Attribute Summary collapse
-
#title ⇒ String
Title of the source; for example a title of a web page or an email subject.
-
#url ⇒ String
URL of the source pointing to a resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
1670 1671 1672 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#title ⇒ String
Title of the source; for example a title of a web page or an email subject.
Corresponds to the JSON property title
1663 1664 1665 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1663 def title @title end |
#url ⇒ String
URL of the source pointing to a resource. The URL scheme must be HTTP or HTTPS.
Corresponds to the JSON property url
1668 1669 1670 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1668 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1675 1676 1677 1678 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1675 def update!(**args) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |