Class: Google::Apis::CalendarV3::EventAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventAttachment

Returns a new instance of EventAttachment.



1742
1743
1744
# File 'lib/google/apis/calendar_v3/classes.rb', line 1742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_idString

ID of the attached file. Read-only. For Google Drive files, this is the ID of the corresponding Files resource entry in the Drive API. Corresponds to the JSON property fileId

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/calendar_v3/classes.rb', line 1716

def file_id
  @file_id
end

#file_urlString

URL link to the attachment. For adding Google Drive file attachments use the same format as in alternateLink property of the Files resource in the Drive API. Required when adding an attachment. Corresponds to the JSON property fileUrl

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/calendar_v3/classes.rb', line 1724

def file_url
  @file_url
end

URL link to the attachment's icon. This field can only be modified for custom third-party attachments. Corresponds to the JSON property iconLink

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/calendar_v3/classes.rb', line 1730

def icon_link
  @icon_link
end

#mime_typeString

Internet media type (MIME type) of the attachment. Corresponds to the JSON property mimeType

Returns:

  • (String)


1735
1736
1737
# File 'lib/google/apis/calendar_v3/classes.rb', line 1735

def mime_type
  @mime_type
end

#titleString

Attachment title. Corresponds to the JSON property title

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/calendar_v3/classes.rb', line 1740

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1747
1748
1749
1750
1751
1752
1753
# File 'lib/google/apis/calendar_v3/classes.rb', line 1747

def update!(**args)
  @file_id = args[:file_id] if args.key?(:file_id)
  @file_url = args[:file_url] if args.key?(:file_url)
  @icon_link = args[:icon_link] if args.key?(:icon_link)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @title = args[:title] if args.key?(:title)
end