Class: Google::Apis::CalendarV3::EventAttachment
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventAttachment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#file_id ⇒ String
ID of the attached file.
-
#file_url ⇒ String
URL link to the attachment.
-
#icon_link ⇒ String
URL link to the attachment's icon.
-
#mime_type ⇒ String
Internet media type (MIME type) of the attachment.
-
#title ⇒ String
Attachment title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventAttachment
constructor
A new instance of EventAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventAttachment
Returns a new instance of EventAttachment.
1721 1722 1723 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_id ⇒ String
ID of the attached file. Read-only.
For Google Drive files, this is the ID of the corresponding Files resource
entry in the Drive API.
Corresponds to the JSON property fileId
1695 1696 1697 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1695 def file_id @file_id end |
#file_url ⇒ String
URL link to the attachment.
For adding Google Drive file attachments use the same format as in
alternateLink property of the Files resource in the Drive API.
Required when adding an attachment.
Corresponds to the JSON property fileUrl
1703 1704 1705 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1703 def file_url @file_url end |
#icon_link ⇒ String
URL link to the attachment's icon. This field can only be modified for custom
third-party attachments.
Corresponds to the JSON property iconLink
1709 1710 1711 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1709 def icon_link @icon_link end |
#mime_type ⇒ String
Internet media type (MIME type) of the attachment.
Corresponds to the JSON property mimeType
1714 1715 1716 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1714 def mime_type @mime_type end |
#title ⇒ String
Attachment title.
Corresponds to the JSON property title
1719 1720 1721 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1719 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1726 1727 1728 1729 1730 1731 1732 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1726 def update!(**args) @file_id = args[:file_id] if args.key?(:file_id) @file_url = args[:file_url] if args.key?(:file_url) @icon_link = args[:icon_link] if args.key?(:icon_link) @mime_type = args[:mime_type] if args.key?(:mime_type) @title = args[:title] if args.key?(:title) end |