Class: Google::Apis::CalendarV3::EventAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventAttachment

Returns a new instance of EventAttachment.



1717
1718
1719
# File 'lib/google/apis/calendar_v3/classes.rb', line 1717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_idString

ID of the attached file. Read-only. For Google Drive files, this is the ID of the corresponding Files resource entry in the Drive API. Corresponds to the JSON property fileId

Returns:

  • (String)


1691
1692
1693
# File 'lib/google/apis/calendar_v3/classes.rb', line 1691

def file_id
  @file_id
end

#file_urlString

URL link to the attachment. For adding Google Drive file attachments use the same format as in alternateLink property of the Files resource in the Drive API. Required when adding an attachment. Corresponds to the JSON property fileUrl

Returns:

  • (String)


1699
1700
1701
# File 'lib/google/apis/calendar_v3/classes.rb', line 1699

def file_url
  @file_url
end

URL link to the attachment's icon. This field can only be modified for custom third-party attachments. Corresponds to the JSON property iconLink

Returns:

  • (String)


1705
1706
1707
# File 'lib/google/apis/calendar_v3/classes.rb', line 1705

def icon_link
  @icon_link
end

#mime_typeString

Internet media type (MIME type) of the attachment. Corresponds to the JSON property mimeType

Returns:

  • (String)


1710
1711
1712
# File 'lib/google/apis/calendar_v3/classes.rb', line 1710

def mime_type
  @mime_type
end

#titleString

Attachment title. Corresponds to the JSON property title

Returns:

  • (String)


1715
1716
1717
# File 'lib/google/apis/calendar_v3/classes.rb', line 1715

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1722
1723
1724
1725
1726
1727
1728
# File 'lib/google/apis/calendar_v3/classes.rb', line 1722

def update!(**args)
  @file_id = args[:file_id] if args.key?(:file_id)
  @file_url = args[:file_url] if args.key?(:file_url)
  @icon_link = args[:icon_link] if args.key?(:icon_link)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @title = args[:title] if args.key?(:title)
end