Class: Google::Apis::CalendarV3::EventAttendee

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventAttendee

Returns a new instance of EventAttendee.



1841
1842
1843
# File 'lib/google/apis/calendar_v3/classes.rb', line 1841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_guestsFixnum

Number of additional guests. Optional. The default is 0. Corresponds to the JSON property additionalGuests

Returns:

  • (Fixnum)


1763
1764
1765
# File 'lib/google/apis/calendar_v3/classes.rb', line 1763

def additional_guests
  @additional_guests
end

#async_operationString

If present, indicates the status of an asynchronous operation ongoing for this attendee (e.g. listing of members of large attendee groups). Read-only. The default is to not be present. Possible values are:

  • "inProgress" - The asynchronous operation is in progress.
  • (not present) - Otherwise. Corresponds to the JSON property asyncOperation

Returns:

  • (String)


1773
1774
1775
# File 'lib/google/apis/calendar_v3/classes.rb', line 1773

def async_operation
  @async_operation
end

#commentString

The attendee's response comment. Optional. Corresponds to the JSON property comment

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/calendar_v3/classes.rb', line 1778

def comment
  @comment
end

#display_nameString

The attendee's name, if available. Optional. Corresponds to the JSON property displayName

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/calendar_v3/classes.rb', line 1783

def display_name
  @display_name
end

#emailString

The attendee's email address, if available. This field must be present when adding an attendee. It must be a valid email address as per RFC5322. Required when adding an attendee. Corresponds to the JSON property email

Returns:

  • (String)


1790
1791
1792
# File 'lib/google/apis/calendar_v3/classes.rb', line 1790

def email
  @email
end

#idString

The attendee's Profile ID, if available. Corresponds to the JSON property id

Returns:

  • (String)


1795
1796
1797
# File 'lib/google/apis/calendar_v3/classes.rb', line 1795

def id
  @id
end

#optionalBoolean Also known as: optional?

Whether this is an optional attendee. Optional. The default is False. Corresponds to the JSON property optional

Returns:

  • (Boolean)


1800
1801
1802
# File 'lib/google/apis/calendar_v3/classes.rb', line 1800

def optional
  @optional
end

#organizerBoolean Also known as: organizer?

Whether the attendee is the organizer of the event. Read-only. The default is False. Corresponds to the JSON property organizer

Returns:

  • (Boolean)


1807
1808
1809
# File 'lib/google/apis/calendar_v3/classes.rb', line 1807

def organizer
  @organizer
end

#resourceBoolean Also known as: resource?

Whether the attendee is a resource. Can only be set when the attendee is added to the event for the first time. Subsequent modifications are ignored. Optional. The default is False. Corresponds to the JSON property resource

Returns:

  • (Boolean)


1815
1816
1817
# File 'lib/google/apis/calendar_v3/classes.rb', line 1815

def resource
  @resource
end

#response_statusString

The attendee's response status. Possible values are:

  • "needsAction" - The attendee has not responded to the invitation ( recommended for new events).
  • "declined" - The attendee has declined the invitation.
  • "tentative" - The attendee has tentatively accepted the invitation.
  • "accepted" - The attendee has accepted the invitation. Warning: If you add an event using the values declined, tentative, or accepted, attendees with the "Add invitations to my calendar" setting set to "When I respond to invitation in email" or "Only if the sender is known" might have their response reset to needsAction and won't see an event in their calendar unless they change their response in the event invitation email. Furthermore, if more than 200 guests are invited to the event, response status is not propagated to the guests. Corresponds to the JSON property responseStatus

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/calendar_v3/classes.rb', line 1832

def response_status
  @response_status
end

#selfBoolean Also known as: self?

Whether this entry represents the calendar on which this copy of the event appears. Read-only. The default is False. Corresponds to the JSON property self

Returns:

  • (Boolean)


1838
1839
1840
# File 'lib/google/apis/calendar_v3/classes.rb', line 1838

def self
  @self
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/google/apis/calendar_v3/classes.rb', line 1846

def update!(**args)
  @additional_guests = args[:additional_guests] if args.key?(:additional_guests)
  @async_operation = args[:async_operation] if args.key?(:async_operation)
  @comment = args[:comment] if args.key?(:comment)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @id = args[:id] if args.key?(:id)
  @optional = args[:optional] if args.key?(:optional)
  @organizer = args[:organizer] if args.key?(:organizer)
  @resource = args[:resource] if args.key?(:resource)
  @response_status = args[:response_status] if args.key?(:response_status)
  @self = args[:self] if args.key?(:self)
end