Class: Google::Apis::CalendarV3::EventAttendee

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventAttendee

Returns a new instance of EventAttendee.



1810
1811
1812
# File 'lib/google/apis/calendar_v3/classes.rb', line 1810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_guestsFixnum

Number of additional guests. Optional. The default is 0. Corresponds to the JSON property additionalGuests

Returns:

  • (Fixnum)


1742
1743
1744
# File 'lib/google/apis/calendar_v3/classes.rb', line 1742

def additional_guests
  @additional_guests
end

#commentString

The attendee's response comment. Optional. Corresponds to the JSON property comment

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/calendar_v3/classes.rb', line 1747

def comment
  @comment
end

#display_nameString

The attendee's name, if available. Optional. Corresponds to the JSON property displayName

Returns:

  • (String)


1752
1753
1754
# File 'lib/google/apis/calendar_v3/classes.rb', line 1752

def display_name
  @display_name
end

#emailString

The attendee's email address, if available. This field must be present when adding an attendee. It must be a valid email address as per RFC5322. Required when adding an attendee. Corresponds to the JSON property email

Returns:

  • (String)


1759
1760
1761
# File 'lib/google/apis/calendar_v3/classes.rb', line 1759

def email
  @email
end

#idString

The attendee's Profile ID, if available. Corresponds to the JSON property id

Returns:

  • (String)


1764
1765
1766
# File 'lib/google/apis/calendar_v3/classes.rb', line 1764

def id
  @id
end

#optionalBoolean Also known as: optional?

Whether this is an optional attendee. Optional. The default is False. Corresponds to the JSON property optional

Returns:

  • (Boolean)


1769
1770
1771
# File 'lib/google/apis/calendar_v3/classes.rb', line 1769

def optional
  @optional
end

#organizerBoolean Also known as: organizer?

Whether the attendee is the organizer of the event. Read-only. The default is False. Corresponds to the JSON property organizer

Returns:

  • (Boolean)


1776
1777
1778
# File 'lib/google/apis/calendar_v3/classes.rb', line 1776

def organizer
  @organizer
end

#resourceBoolean Also known as: resource?

Whether the attendee is a resource. Can only be set when the attendee is added to the event for the first time. Subsequent modifications are ignored. Optional. The default is False. Corresponds to the JSON property resource

Returns:

  • (Boolean)


1784
1785
1786
# File 'lib/google/apis/calendar_v3/classes.rb', line 1784

def resource
  @resource
end

#response_statusString

The attendee's response status. Possible values are:

  • "needsAction" - The attendee has not responded to the invitation ( recommended for new events).
  • "declined" - The attendee has declined the invitation.
  • "tentative" - The attendee has tentatively accepted the invitation.
  • "accepted" - The attendee has accepted the invitation. Warning: If you add an event using the values declined, tentative, or accepted, attendees with the "Add invitations to my calendar" setting set to "When I respond to invitation in email" or "Only if the sender is known" might have their response reset to needsAction and won't see an event in their calendar unless they change their response in the event invitation email. Furthermore, if more than 200 guests are invited to the event, response status is not propagated to the guests. Corresponds to the JSON property responseStatus

Returns:

  • (String)


1801
1802
1803
# File 'lib/google/apis/calendar_v3/classes.rb', line 1801

def response_status
  @response_status
end

#selfBoolean Also known as: self?

Whether this entry represents the calendar on which this copy of the event appears. Read-only. The default is False. Corresponds to the JSON property self

Returns:

  • (Boolean)


1807
1808
1809
# File 'lib/google/apis/calendar_v3/classes.rb', line 1807

def self
  @self
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
# File 'lib/google/apis/calendar_v3/classes.rb', line 1815

def update!(**args)
  @additional_guests = args[:additional_guests] if args.key?(:additional_guests)
  @comment = args[:comment] if args.key?(:comment)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @id = args[:id] if args.key?(:id)
  @optional = args[:optional] if args.key?(:optional)
  @organizer = args[:organizer] if args.key?(:organizer)
  @resource = args[:resource] if args.key?(:resource)
  @response_status = args[:response_status] if args.key?(:response_status)
  @self = args[:self] if args.key?(:self)
end