Class: Google::Apis::CalendarV3::EventAttendee
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventAttendee
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#additional_guests ⇒ Fixnum
Number of additional guests.
-
#comment ⇒ String
The attendee's response comment.
-
#display_name ⇒ String
The attendee's name, if available.
-
#email ⇒ String
The attendee's email address, if available.
-
#id ⇒ String
The attendee's Profile ID, if available.
-
#optional ⇒ Boolean
(also: #optional?)
Whether this is an optional attendee.
-
#organizer ⇒ Boolean
(also: #organizer?)
Whether the attendee is the organizer of the event.
-
#resource ⇒ Boolean
(also: #resource?)
Whether the attendee is a resource.
-
#response_status ⇒ String
The attendee's response status.
-
#self ⇒ Boolean
(also: #self?)
Whether this entry represents the calendar on which this copy of the event appears.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventAttendee
constructor
A new instance of EventAttendee.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventAttendee
Returns a new instance of EventAttendee.
1806 1807 1808 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_guests ⇒ Fixnum
Number of additional guests. Optional. The default is 0.
Corresponds to the JSON property additionalGuests
1738 1739 1740 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1738 def additional_guests @additional_guests end |
#comment ⇒ String
The attendee's response comment. Optional.
Corresponds to the JSON property comment
1743 1744 1745 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1743 def comment @comment end |
#display_name ⇒ String
The attendee's name, if available. Optional.
Corresponds to the JSON property displayName
1748 1749 1750 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1748 def display_name @display_name end |
#email ⇒ String
The attendee's email address, if available. This field must be present when
adding an attendee. It must be a valid email address as per RFC5322.
Required when adding an attendee.
Corresponds to the JSON property email
1755 1756 1757 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1755 def email @email end |
#id ⇒ String
The attendee's Profile ID, if available.
Corresponds to the JSON property id
1760 1761 1762 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1760 def id @id end |
#optional ⇒ Boolean Also known as: optional?
Whether this is an optional attendee. Optional. The default is False.
Corresponds to the JSON property optional
1765 1766 1767 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1765 def optional @optional end |
#organizer ⇒ Boolean Also known as: organizer?
Whether the attendee is the organizer of the event. Read-only. The default is
False.
Corresponds to the JSON property organizer
1772 1773 1774 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1772 def organizer @organizer end |
#resource ⇒ Boolean Also known as: resource?
Whether the attendee is a resource. Can only be set when the attendee is added
to the event for the first time. Subsequent modifications are ignored.
Optional. The default is False.
Corresponds to the JSON property resource
1780 1781 1782 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1780 def resource @resource end |
#response_status ⇒ String
The attendee's response status. Possible values are:
- "needsAction" - The attendee has not responded to the invitation ( recommended for new events).
- "declined" - The attendee has declined the invitation.
- "tentative" - The attendee has tentatively accepted the invitation.
- "accepted" - The attendee has accepted the invitation. Warning: If you add
an event using the values declined, tentative, or accepted, attendees with the
"Add invitations to my calendar" setting set to "When I respond to invitation
in email" or "Only if the sender is known" might have their response reset to
needsAction and won't see an event in their calendar unless they change their
response in the event invitation email. Furthermore, if more than 200 guests
are invited to the event, response status is not propagated to the guests.
Corresponds to the JSON property
responseStatus
1797 1798 1799 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1797 def response_status @response_status end |
#self ⇒ Boolean Also known as: self?
Whether this entry represents the calendar on which this copy of the event
appears. Read-only. The default is False.
Corresponds to the JSON property self
1803 1804 1805 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1803 def self @self end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1811 def update!(**args) @additional_guests = args[:additional_guests] if args.key?(:additional_guests) @comment = args[:comment] if args.key?(:comment) @display_name = args[:display_name] if args.key?(:display_name) @email = args[:email] if args.key?(:email) @id = args[:id] if args.key?(:id) @optional = args[:optional] if args.key?(:optional) @organizer = args[:organizer] if args.key?(:organizer) @resource = args[:resource] if args.key?(:resource) @response_status = args[:response_status] if args.key?(:response_status) @self = args[:self] if args.key?(:self) end |