Class: Google::Apis::CalendarV3::EventBirthdayProperties
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventBirthdayProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#contact ⇒ String
Resource name of the contact this birthday event is linked to.
-
#custom_type_name ⇒ String
Custom type label specified for this event.
-
#type ⇒ String
Type of birthday or special event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventBirthdayProperties
constructor
A new instance of EventBirthdayProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventBirthdayProperties
Returns a new instance of EventBirthdayProperties.
1856 1857 1858 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contact ⇒ String
Resource name of the contact this birthday event is linked to. This can be
used to fetch contact details from People API. Format: "people/c12345". Read-
only.
Corresponds to the JSON property contact
1834 1835 1836 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1834 def contact @contact end |
#custom_type_name ⇒ String
Custom type label specified for this event. This is populated if
birthdayProperties.type is set to "custom". Read-only.
Corresponds to the JSON property customTypeName
1840 1841 1842 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1840 def custom_type_name @custom_type_name end |
#type ⇒ String
Type of birthday or special event. Possible values are:
- "anniversary" - An anniversary other than birthday. Always has a contact.
- "birthday" - A birthday event. This is the default value.
- "custom" - A special date whose label is further specified in the customTypeName field. Always has a contact.
- "other" - A special date which does not fall into the other categories, and does not have a custom label. Always has a contact.
- "self" - Calendar owner's own birthday. Cannot have a contact. The Calendar
API only supports creating events with the type "birthday". The type cannot be
changed after the event is created.
Corresponds to the JSON property
type
1854 1855 1856 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1854 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1861 1862 1863 1864 1865 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1861 def update!(**args) @contact = args[:contact] if args.key?(:contact) @custom_type_name = args[:custom_type_name] if args.key?(:custom_type_name) @type = args[:type] if args.key?(:type) end |