Class: Google::Apis::CalendarV3::EventFocusTimeProperties
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventFocusTimeProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#auto_decline_mode ⇒ String
Whether to decline meeting invitations which overlap Focus Time events.
-
#chat_status ⇒ String
The status to mark the user in Chat and related products.
-
#decline_message ⇒ String
Response message to set if an existing event or new invitation is automatically declined by Calendar.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventFocusTimeProperties
constructor
A new instance of EventFocusTimeProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventFocusTimeProperties
Returns a new instance of EventFocusTimeProperties.
1932 1933 1934 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_decline_mode ⇒ String
Whether to decline meeting invitations which overlap Focus Time events. Valid
values are declineNone, meaning that no meeting invitations are declined;
declineAllConflictingInvitations, meaning that all conflicting meeting
invitations that conflict with the event are declined; and
declineOnlyNewConflictingInvitations, meaning that only new conflicting
meeting invitations which arrive while the Focus Time event is present are to
be declined.
Corresponds to the JSON property autoDeclineMode
1918 1919 1920 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1918 def auto_decline_mode @auto_decline_mode end |
#chat_status ⇒ String
The status to mark the user in Chat and related products. This can be
available or doNotDisturb.
Corresponds to the JSON property chatStatus
1924 1925 1926 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1924 def chat_status @chat_status end |
#decline_message ⇒ String
Response message to set if an existing event or new invitation is
automatically declined by Calendar.
Corresponds to the JSON property declineMessage
1930 1931 1932 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1930 def @decline_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1937 1938 1939 1940 1941 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1937 def update!(**args) @auto_decline_mode = args[:auto_decline_mode] if args.key?(:auto_decline_mode) @chat_status = args[:chat_status] if args.key?(:chat_status) @decline_message = args[:decline_message] if args.key?(:decline_message) end |