Class: Google::Apis::CalendarV3::EventOutOfOfficeProperties
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventOutOfOfficeProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#auto_decline_mode ⇒ String
Whether to decline meeting invitations which overlap Out of office events.
-
#decline_message ⇒ String
Response message to set if an existing event or new invitation is automatically declined by Calendar.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventOutOfOfficeProperties
constructor
A new instance of EventOutOfOfficeProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventOutOfOfficeProperties
Returns a new instance of EventOutOfOfficeProperties.
1993 1994 1995 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_decline_mode ⇒ String
Whether to decline meeting invitations which overlap Out of office events.
Valid values are declineNone, meaning that no meeting invitations are declined;
declineAllConflictingInvitations, meaning that all conflicting meeting
invitations that conflict with the event are declined; and
declineOnlyNewConflictingInvitations, meaning that only new conflicting
meeting invitations which arrive while the Out of office event is present are
to be declined.
Corresponds to the JSON property autoDeclineMode
1985 1986 1987 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1985 def auto_decline_mode @auto_decline_mode end |
#decline_message ⇒ String
Response message to set if an existing event or new invitation is
automatically declined by Calendar.
Corresponds to the JSON property declineMessage
1991 1992 1993 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1991 def @decline_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1998 1999 2000 2001 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 1998 def update!(**args) @auto_decline_mode = args[:auto_decline_mode] if args.key?(:auto_decline_mode) @decline_message = args[:decline_message] if args.key?(:decline_message) end |