Class: Google::Apis::CalendarV3::EventWorkingLocationProperties
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::EventWorkingLocationProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Defined Under Namespace
Classes: CustomLocation, OfficeLocation
Instance Attribute Summary collapse
-
#custom_location ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties::CustomLocation
If present, specifies that the user is working from a custom location.
-
#home_office ⇒ Object
If present, specifies that the user is working at home.
-
#office_location ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation
If present, specifies that the user is working from an office.
-
#type ⇒ String
Type of the working location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventWorkingLocationProperties
constructor
A new instance of EventWorkingLocationProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventWorkingLocationProperties
Returns a new instance of EventWorkingLocationProperties.
2064 2065 2066 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_location ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties::CustomLocation
If present, specifies that the user is working from a custom location.
Corresponds to the JSON property customLocation
2041 2042 2043 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2041 def custom_location @custom_location end |
#home_office ⇒ Object
If present, specifies that the user is working at home.
Corresponds to the JSON property homeOffice
2046 2047 2048 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2046 def home_office @home_office end |
#office_location ⇒ Google::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation
If present, specifies that the user is working from an office.
Corresponds to the JSON property officeLocation
2051 2052 2053 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2051 def office_location @office_location end |
#type ⇒ String
Type of the working location. Possible values are:
- "homeOffice" - The user is working at home.
- "officeLocation" - The user is working from an office.
- "customLocation" - The user is working from a custom location. Any details
are specified in a sub-field of the specified name, but this field may be
missing if empty. Any other fields are ignored.
Required when adding working location properties.
Corresponds to the JSON property
type
2062 2063 2064 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2062 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2069 2070 2071 2072 2073 2074 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2069 def update!(**args) @custom_location = args[:custom_location] if args.key?(:custom_location) @home_office = args[:home_office] if args.key?(:home_office) @office_location = args[:office_location] if args.key?(:office_location) @type = args[:type] if args.key?(:type) end |