Class: Google::Apis::CalendarV3::EventWorkingLocationProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Defined Under Namespace

Classes: CustomLocation, OfficeLocation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventWorkingLocationProperties

Returns a new instance of EventWorkingLocationProperties.



2036
2037
2038
# File 'lib/google/apis/calendar_v3/classes.rb', line 2036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_locationGoogle::Apis::CalendarV3::EventWorkingLocationProperties::CustomLocation

If present, specifies that the user is working from a custom location. Corresponds to the JSON property customLocation



2013
2014
2015
# File 'lib/google/apis/calendar_v3/classes.rb', line 2013

def custom_location
  @custom_location
end

#home_officeObject

If present, specifies that the user is working at home. Corresponds to the JSON property homeOffice

Returns:

  • (Object)


2018
2019
2020
# File 'lib/google/apis/calendar_v3/classes.rb', line 2018

def home_office
  @home_office
end

#office_locationGoogle::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation

If present, specifies that the user is working from an office. Corresponds to the JSON property officeLocation



2023
2024
2025
# File 'lib/google/apis/calendar_v3/classes.rb', line 2023

def office_location
  @office_location
end

#typeString

Type of the working location. Possible values are:

  • "homeOffice" - The user is working at home.
  • "officeLocation" - The user is working from an office.
  • "customLocation" - The user is working from a custom location. Any details are specified in a sub-field of the specified name, but this field may be missing if empty. Any other fields are ignored. Required when adding working location properties. Corresponds to the JSON property type

Returns:

  • (String)


2034
2035
2036
# File 'lib/google/apis/calendar_v3/classes.rb', line 2034

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2041
2042
2043
2044
2045
2046
# File 'lib/google/apis/calendar_v3/classes.rb', line 2041

def update!(**args)
  @custom_location = args[:custom_location] if args.key?(:custom_location)
  @home_office = args[:home_office] if args.key?(:home_office)
  @office_location = args[:office_location] if args.key?(:office_location)
  @type = args[:type] if args.key?(:type)
end