Class: Google::Apis::CalendarV3::EventWorkingLocationProperties::OfficeLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Overview

If present, specifies that the user is working from an office.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OfficeLocation

Returns a new instance of OfficeLocation.



2127
2128
2129
# File 'lib/google/apis/calendar_v3/classes.rb', line 2127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#building_idString

An optional building identifier. This should reference a building ID in the organization's Resources database. Corresponds to the JSON property buildingId

Returns:

  • (String)


2103
2104
2105
# File 'lib/google/apis/calendar_v3/classes.rb', line 2103

def building_id
  @building_id
end

#desk_idString

An optional desk identifier. Corresponds to the JSON property deskId

Returns:

  • (String)


2108
2109
2110
# File 'lib/google/apis/calendar_v3/classes.rb', line 2108

def desk_id
  @desk_id
end

#floor_idString

An optional floor identifier. Corresponds to the JSON property floorId

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/calendar_v3/classes.rb', line 2113

def floor_id
  @floor_id
end

#floor_section_idString

An optional floor section identifier. Corresponds to the JSON property floorSectionId

Returns:

  • (String)


2118
2119
2120
# File 'lib/google/apis/calendar_v3/classes.rb', line 2118

def floor_section_id
  @floor_section_id
end

#labelString

The office name that's displayed in Calendar Web and Mobile clients. We recommend you reference a building name in the organization's Resources database. Corresponds to the JSON property label

Returns:

  • (String)


2125
2126
2127
# File 'lib/google/apis/calendar_v3/classes.rb', line 2125

def label
  @label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2132
2133
2134
2135
2136
2137
2138
# File 'lib/google/apis/calendar_v3/classes.rb', line 2132

def update!(**args)
  @building_id = args[:building_id] if args.key?(:building_id)
  @desk_id = args[:desk_id] if args.key?(:desk_id)
  @floor_id = args[:floor_id] if args.key?(:floor_id)
  @floor_section_id = args[:floor_section_id] if args.key?(:floor_section_id)
  @label = args[:label] if args.key?(:label)
end