Class: Google::Apis::CalendarV3::Events

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Events

Returns a new instance of Events.



2261
2262
2263
# File 'lib/google/apis/calendar_v3/classes.rb', line 2261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_roleString

The user's access role for this calendar. Read-only. Possible values are:

  • "none" - The user has no access.
  • "freeBusyReader" - The user has read access to free/busy information.
  • "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
  • "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible.
  • "owner" - The user has manager access to the calendar. This role has all of the permissions of the writer role with the additional ability to see and modify access levels of other users. Important: the owner role is different from the calendar's data owner. A calendar has a single data owner, but can have multiple users with owner role. Corresponds to the JSON property accessRole

Returns:

  • (String)


2204
2205
2206
# File 'lib/google/apis/calendar_v3/classes.rb', line 2204

def access_role
  @access_role
end

#default_remindersArray<Google::Apis::CalendarV3::EventReminder>

The default reminders on the calendar for the authenticated user. These reminders apply to all events on this calendar that do not explicitly override them (i.e. do not have reminders.useDefault set to True). Corresponds to the JSON property defaultReminders



2211
2212
2213
# File 'lib/google/apis/calendar_v3/classes.rb', line 2211

def default_reminders
  @default_reminders
end

#descriptionString

Description of the calendar. Read-only. Corresponds to the JSON property description

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/calendar_v3/classes.rb', line 2216

def description
  @description
end

#etagString

ETag of the collection. Corresponds to the JSON property etag

Returns:

  • (String)


2221
2222
2223
# File 'lib/google/apis/calendar_v3/classes.rb', line 2221

def etag
  @etag
end

#itemsArray<Google::Apis::CalendarV3::Event>

List of events on the calendar. Corresponds to the JSON property items



2226
2227
2228
# File 'lib/google/apis/calendar_v3/classes.rb', line 2226

def items
  @items
end

#kindString

Type of the collection ("calendar#events"). Corresponds to the JSON property kind

Returns:

  • (String)


2231
2232
2233
# File 'lib/google/apis/calendar_v3/classes.rb', line 2231

def kind
  @kind
end

#next_page_tokenString

Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/calendar_v3/classes.rb', line 2237

def next_page_token
  @next_page_token
end

#next_sync_tokenString

Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided. Corresponds to the JSON property nextSyncToken

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/calendar_v3/classes.rb', line 2244

def next_sync_token
  @next_sync_token
end

#summaryString

Title of the calendar. Read-only. Corresponds to the JSON property summary

Returns:

  • (String)


2249
2250
2251
# File 'lib/google/apis/calendar_v3/classes.rb', line 2249

def summary
  @summary
end

#time_zoneString

The time zone of the calendar. Read-only. Corresponds to the JSON property timeZone

Returns:

  • (String)


2254
2255
2256
# File 'lib/google/apis/calendar_v3/classes.rb', line 2254

def time_zone
  @time_zone
end

#updatedDateTime

Last modification time of the calendar (as a RFC3339 timestamp). Read-only. Corresponds to the JSON property updated

Returns:

  • (DateTime)


2259
2260
2261
# File 'lib/google/apis/calendar_v3/classes.rb', line 2259

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
# File 'lib/google/apis/calendar_v3/classes.rb', line 2266

def update!(**args)
  @access_role = args[:access_role] if args.key?(:access_role)
  @default_reminders = args[:default_reminders] if args.key?(:default_reminders)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token)
  @summary = args[:summary] if args.key?(:summary)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @updated = args[:updated] if args.key?(:updated)
end