Class: Google::Apis::CalendarV3::Events

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Events

Returns a new instance of Events.



2218
2219
2220
# File 'lib/google/apis/calendar_v3/classes.rb', line 2218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_roleString

The user's access role for this calendar. Read-only. Possible values are:

  • "none" - The user has no access.
  • "freeBusyReader" - The user has read access to free/busy information.
  • "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
  • "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible.
  • "owner" - The user has manager access to the calendar. This role has all of the permissions of the writer role with the additional ability to see and modify access levels of other users. Important: the owner role is different from the calendar's data owner. A calendar has a single data owner, but can have multiple users with owner role. Corresponds to the JSON property accessRole

Returns:

  • (String)


2161
2162
2163
# File 'lib/google/apis/calendar_v3/classes.rb', line 2161

def access_role
  @access_role
end

#default_remindersArray<Google::Apis::CalendarV3::EventReminder>

The default reminders on the calendar for the authenticated user. These reminders apply to all events on this calendar that do not explicitly override them (i.e. do not have reminders.useDefault set to True). Corresponds to the JSON property defaultReminders



2168
2169
2170
# File 'lib/google/apis/calendar_v3/classes.rb', line 2168

def default_reminders
  @default_reminders
end

#descriptionString

Description of the calendar. Read-only. Corresponds to the JSON property description

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/calendar_v3/classes.rb', line 2173

def description
  @description
end

#etagString

ETag of the collection. Corresponds to the JSON property etag

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/calendar_v3/classes.rb', line 2178

def etag
  @etag
end

#itemsArray<Google::Apis::CalendarV3::Event>

List of events on the calendar. Corresponds to the JSON property items



2183
2184
2185
# File 'lib/google/apis/calendar_v3/classes.rb', line 2183

def items
  @items
end

#kindString

Type of the collection ("calendar#events"). Corresponds to the JSON property kind

Returns:

  • (String)


2188
2189
2190
# File 'lib/google/apis/calendar_v3/classes.rb', line 2188

def kind
  @kind
end

#next_page_tokenString

Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/calendar_v3/classes.rb', line 2194

def next_page_token
  @next_page_token
end

#next_sync_tokenString

Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided. Corresponds to the JSON property nextSyncToken

Returns:

  • (String)


2201
2202
2203
# File 'lib/google/apis/calendar_v3/classes.rb', line 2201

def next_sync_token
  @next_sync_token
end

#summaryString

Title of the calendar. Read-only. Corresponds to the JSON property summary

Returns:

  • (String)


2206
2207
2208
# File 'lib/google/apis/calendar_v3/classes.rb', line 2206

def summary
  @summary
end

#time_zoneString

The time zone of the calendar. Read-only. Corresponds to the JSON property timeZone

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/calendar_v3/classes.rb', line 2211

def time_zone
  @time_zone
end

#updatedDateTime

Last modification time of the calendar (as a RFC3339 timestamp). Read-only. Corresponds to the JSON property updated

Returns:

  • (DateTime)


2216
2217
2218
# File 'lib/google/apis/calendar_v3/classes.rb', line 2216

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
# File 'lib/google/apis/calendar_v3/classes.rb', line 2223

def update!(**args)
  @access_role = args[:access_role] if args.key?(:access_role)
  @default_reminders = args[:default_reminders] if args.key?(:default_reminders)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token)
  @summary = args[:summary] if args.key?(:summary)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @updated = args[:updated] if args.key?(:updated)
end