Class: Google::Apis::CalendarV3::Events
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Events
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#access_role ⇒ String
The user's access role for this calendar.
-
#default_reminders ⇒ Array<Google::Apis::CalendarV3::EventReminder>
The default reminders on the calendar for the authenticated user.
-
#description ⇒ String
Description of the calendar.
-
#etag ⇒ String
ETag of the collection.
-
#items ⇒ Array<Google::Apis::CalendarV3::Event>
List of events on the calendar.
-
#kind ⇒ String
Type of the collection ("calendar#events").
-
#next_page_token ⇒ String
Token used to access the next page of this result.
-
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
-
#summary ⇒ String
Title of the calendar.
-
#time_zone ⇒ String
The time zone of the calendar.
-
#updated ⇒ DateTime
Last modification time of the calendar (as a RFC3339 timestamp).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Events
constructor
A new instance of Events.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Events
Returns a new instance of Events.
2194 2195 2196 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_role ⇒ String
The user's access role for this calendar. Read-only. Possible values are:
- "none" - The user has no access.
- "freeBusyReader" - The user has read access to free/busy information.
- "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
- "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible.
- "owner" - The user has manager access to the calendar. This role has all of
the permissions of the writer role with the additional ability to see and
modify access levels of other users.
Important: the owner role is different from the calendar's data owner. A
calendar has a single data owner, but can have multiple users with owner role.
Corresponds to the JSON property
accessRole
2137 2138 2139 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2137 def access_role @access_role end |
#default_reminders ⇒ Array<Google::Apis::CalendarV3::EventReminder>
The default reminders on the calendar for the authenticated user. These
reminders apply to all events on this calendar that do not explicitly override
them (i.e. do not have reminders.useDefault set to True).
Corresponds to the JSON property defaultReminders
2144 2145 2146 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2144 def default_reminders @default_reminders end |
#description ⇒ String
Description of the calendar. Read-only.
Corresponds to the JSON property description
2149 2150 2151 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2149 def description @description end |
#etag ⇒ String
ETag of the collection.
Corresponds to the JSON property etag
2154 2155 2156 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2154 def etag @etag end |
#items ⇒ Array<Google::Apis::CalendarV3::Event>
List of events on the calendar.
Corresponds to the JSON property items
2159 2160 2161 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2159 def items @items end |
#kind ⇒ String
Type of the collection ("calendar#events").
Corresponds to the JSON property kind
2164 2165 2166 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2164 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. Omitted if no further
results are available, in which case nextSyncToken is provided.
Corresponds to the JSON property nextPageToken
2170 2171 2172 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2170 def next_page_token @next_page_token end |
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have
changed since this result was returned. Omitted if further results are
available, in which case nextPageToken is provided.
Corresponds to the JSON property nextSyncToken
2177 2178 2179 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2177 def next_sync_token @next_sync_token end |
#summary ⇒ String
Title of the calendar. Read-only.
Corresponds to the JSON property summary
2182 2183 2184 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2182 def summary @summary end |
#time_zone ⇒ String
The time zone of the calendar. Read-only.
Corresponds to the JSON property timeZone
2187 2188 2189 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2187 def time_zone @time_zone end |
#updated ⇒ DateTime
Last modification time of the calendar (as a RFC3339 timestamp). Read-only.
Corresponds to the JSON property updated
2192 2193 2194 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2192 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2199 def update!(**args) @access_role = args[:access_role] if args.key?(:access_role) @default_reminders = args[:default_reminders] if args.key?(:default_reminders) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token) @summary = args[:summary] if args.key?(:summary) @time_zone = args[:time_zone] if args.key?(:time_zone) @updated = args[:updated] if args.key?(:updated) end |