Class: Google::Apis::CalendarV3::Events
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Events
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#access_role ⇒ String
The user's access role for this calendar.
-
#default_reminders ⇒ Array<Google::Apis::CalendarV3::EventReminder>
The default reminders on the calendar for the authenticated user.
-
#description ⇒ String
Description of the calendar.
-
#etag ⇒ String
ETag of the collection.
-
#items ⇒ Array<Google::Apis::CalendarV3::Event>
List of events on the calendar.
-
#kind ⇒ String
Type of the collection ("calendar#events").
-
#next_page_token ⇒ String
Token used to access the next page of this result.
-
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
-
#summary ⇒ String
Title of the calendar.
-
#time_zone ⇒ String
The time zone of the calendar.
-
#updated ⇒ DateTime
Last modification time of the calendar (as a RFC3339 timestamp).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Events
constructor
A new instance of Events.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Events
Returns a new instance of Events.
2190 2191 2192 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_role ⇒ String
The user's access role for this calendar. Read-only. Possible values are:
- "none" - The user has no access.
- "freeBusyReader" - The user has read access to free/busy information.
- "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
- "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible.
- "owner" - The user has manager access to the calendar. This role has all of
the permissions of the writer role with the additional ability to see and
modify access levels of other users.
Important: the owner role is different from the calendar's data owner. A
calendar has a single data owner, but can have multiple users with owner role.
Corresponds to the JSON property
accessRole
2133 2134 2135 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2133 def access_role @access_role end |
#default_reminders ⇒ Array<Google::Apis::CalendarV3::EventReminder>
The default reminders on the calendar for the authenticated user. These
reminders apply to all events on this calendar that do not explicitly override
them (i.e. do not have reminders.useDefault set to True).
Corresponds to the JSON property defaultReminders
2140 2141 2142 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2140 def default_reminders @default_reminders end |
#description ⇒ String
Description of the calendar. Read-only.
Corresponds to the JSON property description
2145 2146 2147 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2145 def description @description end |
#etag ⇒ String
ETag of the collection.
Corresponds to the JSON property etag
2150 2151 2152 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2150 def etag @etag end |
#items ⇒ Array<Google::Apis::CalendarV3::Event>
List of events on the calendar.
Corresponds to the JSON property items
2155 2156 2157 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2155 def items @items end |
#kind ⇒ String
Type of the collection ("calendar#events").
Corresponds to the JSON property kind
2160 2161 2162 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2160 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. Omitted if no further
results are available, in which case nextSyncToken is provided.
Corresponds to the JSON property nextPageToken
2166 2167 2168 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2166 def next_page_token @next_page_token end |
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have
changed since this result was returned. Omitted if further results are
available, in which case nextPageToken is provided.
Corresponds to the JSON property nextSyncToken
2173 2174 2175 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2173 def next_sync_token @next_sync_token end |
#summary ⇒ String
Title of the calendar. Read-only.
Corresponds to the JSON property summary
2178 2179 2180 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2178 def summary @summary end |
#time_zone ⇒ String
The time zone of the calendar. Read-only.
Corresponds to the JSON property timeZone
2183 2184 2185 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2183 def time_zone @time_zone end |
#updated ⇒ DateTime
Last modification time of the calendar (as a RFC3339 timestamp). Read-only.
Corresponds to the JSON property updated
2188 2189 2190 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2188 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2195 def update!(**args) @access_role = args[:access_role] if args.key?(:access_role) @default_reminders = args[:default_reminders] if args.key?(:default_reminders) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token) @summary = args[:summary] if args.key?(:summary) @time_zone = args[:time_zone] if args.key?(:time_zone) @updated = args[:updated] if args.key?(:updated) end |