Class: Google::Apis::CalendarV3::FreeBusyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FreeBusyRequest

Returns a new instance of FreeBusyRequest.



2297
2298
2299
# File 'lib/google/apis/calendar_v3/classes.rb', line 2297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calendar_expansion_maxFixnum

Maximal number of calendars for which FreeBusy information is to be provided. Optional. Maximum value is 50. Corresponds to the JSON property calendarExpansionMax

Returns:

  • (Fixnum)


2268
2269
2270
# File 'lib/google/apis/calendar_v3/classes.rb', line 2268

def calendar_expansion_max
  @calendar_expansion_max
end

#group_expansion_maxFixnum

Maximal number of calendar identifiers to be provided for a single group. Optional. An error is returned for a group with more members than this value. Maximum value is 100. Corresponds to the JSON property groupExpansionMax

Returns:

  • (Fixnum)


2275
2276
2277
# File 'lib/google/apis/calendar_v3/classes.rb', line 2275

def group_expansion_max
  @group_expansion_max
end

#itemsArray<Google::Apis::CalendarV3::FreeBusyRequestItem>

List of calendars and/or groups to query. Corresponds to the JSON property items



2280
2281
2282
# File 'lib/google/apis/calendar_v3/classes.rb', line 2280

def items
  @items
end

#time_maxDateTime

The end of the interval for the query formatted as per RFC3339. Corresponds to the JSON property timeMax

Returns:

  • (DateTime)


2285
2286
2287
# File 'lib/google/apis/calendar_v3/classes.rb', line 2285

def time_max
  @time_max
end

#time_minDateTime

The start of the interval for the query formatted as per RFC3339. Corresponds to the JSON property timeMin

Returns:

  • (DateTime)


2290
2291
2292
# File 'lib/google/apis/calendar_v3/classes.rb', line 2290

def time_min
  @time_min
end

#time_zoneString

Time zone used in the response. Optional. The default is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


2295
2296
2297
# File 'lib/google/apis/calendar_v3/classes.rb', line 2295

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2302
2303
2304
2305
2306
2307
2308
2309
# File 'lib/google/apis/calendar_v3/classes.rb', line 2302

def update!(**args)
  @calendar_expansion_max = args[:calendar_expansion_max] if args.key?(:calendar_expansion_max)
  @group_expansion_max = args[:group_expansion_max] if args.key?(:group_expansion_max)
  @items = args[:items] if args.key?(:items)
  @time_max = args[:time_max] if args.key?(:time_max)
  @time_min = args[:time_min] if args.key?(:time_min)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end