Class: Google::Apis::CalendarV3::LabelProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LabelProperties

Returns a new instance of LabelProperties.



2458
2459
2460
# File 'lib/google/apis/calendar_v3/classes.rb', line 2458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_labelsArray<Google::Apis::CalendarV3::EventLabel>

Event labels defined on this calendar. If this is present when updating the calendar, it will replace the existing event labels. Extend the list to add a new event label, and remove entities from the list to delete a label from calendar. Each calendar can have a maximum of 200 labels. Corresponds to the JSON property eventLabels



2456
2457
2458
# File 'lib/google/apis/calendar_v3/classes.rb', line 2456

def event_labels
  @event_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2463
2464
2465
# File 'lib/google/apis/calendar_v3/classes.rb', line 2463

def update!(**args)
  @event_labels = args[:event_labels] if args.key?(:event_labels)
end