Class: Google::Apis::CalendarV3::Settings
- Inherits:
-
Object
- Object
- Google::Apis::CalendarV3::Settings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of the collection.
-
#items ⇒ Array<Google::Apis::CalendarV3::Setting>
List of user settings.
-
#kind ⇒ String
Type of the collection ("calendar#settings").
-
#next_page_token ⇒ String
Token used to access the next page of this result.
-
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Settings
constructor
A new instance of Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Settings
Returns a new instance of Settings.
2448 2449 2450 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of the collection.
Corresponds to the JSON property etag
2423 2424 2425 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2423 def etag @etag end |
#items ⇒ Array<Google::Apis::CalendarV3::Setting>
List of user settings.
Corresponds to the JSON property items
2428 2429 2430 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2428 def items @items end |
#kind ⇒ String
Type of the collection ("calendar#settings").
Corresponds to the JSON property kind
2433 2434 2435 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2433 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. Omitted if no further
results are available, in which case nextSyncToken is provided.
Corresponds to the JSON property nextPageToken
2439 2440 2441 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2439 def next_page_token @next_page_token end |
#next_sync_token ⇒ String
Token used at a later point in time to retrieve only the entries that have
changed since this result was returned. Omitted if further results are
available, in which case nextPageToken is provided.
Corresponds to the JSON property nextSyncToken
2446 2447 2448 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2446 def next_sync_token @next_sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2453 2454 2455 2456 2457 2458 2459 |
# File 'lib/google/apis/calendar_v3/classes.rb', line 2453 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token) end |