Class: Google::Apis::CalendarV3::Settings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/calendar_v3/classes.rb,
lib/google/apis/calendar_v3/representations.rb,
lib/google/apis/calendar_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



2444
2445
2446
# File 'lib/google/apis/calendar_v3/classes.rb', line 2444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of the collection. Corresponds to the JSON property etag

Returns:

  • (String)


2419
2420
2421
# File 'lib/google/apis/calendar_v3/classes.rb', line 2419

def etag
  @etag
end

#itemsArray<Google::Apis::CalendarV3::Setting>

List of user settings. Corresponds to the JSON property items



2424
2425
2426
# File 'lib/google/apis/calendar_v3/classes.rb', line 2424

def items
  @items
end

#kindString

Type of the collection ("calendar#settings"). Corresponds to the JSON property kind

Returns:

  • (String)


2429
2430
2431
# File 'lib/google/apis/calendar_v3/classes.rb', line 2429

def kind
  @kind
end

#next_page_tokenString

Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/calendar_v3/classes.rb', line 2435

def next_page_token
  @next_page_token
end

#next_sync_tokenString

Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided. Corresponds to the JSON property nextSyncToken

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/calendar_v3/classes.rb', line 2442

def next_sync_token
  @next_sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2449
2450
2451
2452
2453
2454
2455
# File 'lib/google/apis/calendar_v3/classes.rb', line 2449

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @next_sync_token = args[:next_sync_token] if args.key?(:next_sync_token)
end